(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    235719,       4060]*)
(*NotebookOutlinePosition[    288792,       5781]*)
(*  CellTagsIndexPosition[    288748,       5777]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Study of the Damped LinearOscillator", "Subtitle"],

Cell["Introduce Notation:", "Text"],

Cell[BoxData[
    \(\(<< Utilities`Notation`;\)\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Symbolize", "[", 
        TagBox[\(\[Omega]\_0\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}], ";", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(a\_0\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}], ";"}]], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Symbolize", "[", 
        TagBox[\(x\_0\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}], ";", 
      RowBox[{"Symbolize", "[", 
        TagBox[\(v\_0\),
          NotationBoxTag,
          TagStyle->"NotationTemplateStyle"], "]"}], ";"}]], "Input"],

Cell["\<\
The solution for general values of the parameters. Notice that when \
the quantity under the square root is negative, we obtain oscillatory \
solutions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(x''\)[
            t] + \[Gamma]\ \(x'\)[t] + \ \(\(\[Omega]\_0\)\(\ \)\)\^2\ x[
              t]\  \[Equal] \ 0, x, t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) - \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\)\ C[
                  1] + \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) + \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\)\ C[2]]}}\)], "Output"]
}, Open  ]],

Cell["Here we add the external force:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol\  = \ 
      DSolve[\(x''\)[
              t] + \[Gamma]\ \(x'\)[t] + \ \[Omega]\_0\^2\ x[t]\  \[Equal] \ 
          a\_0\ Cos[\[Omega]\ t], x, t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) - \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\)\ C[
                  1] + \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) + \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\)\ C[
                  2] - \(4\ \((\(-a\_0\)\ \[Omega]\^2\ Cos[t\ \[Omega]] + \
a\_0\ \[Omega]\_0\%2\ Cos[t\ \[Omega]] + a\_0\ \[Gamma]\ \[Omega]\ Sin[t\ \
\[Omega]])\)\)\/\(\((\[Gamma]\^2 + 2\ \[Omega]\^2 - 2\ \[Omega]\_0\%2 + \
\[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \
\[Omega]\^2 + 2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\)]}}\)], "Output"]
}, Open  ]],

Cell["The degenerate solution:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[\(x''\)[
            t] + \[Gamma]\ \(x'\)[t] + \ \[Gamma]\^2\/4\ x[t]\  \[Equal] \ 0, 
      x, t]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] 
          Function[{t}, \[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ C[
                  1] + \[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ t\ C[
                  2]]}}\)], "Output"]
}, Open  ]],

Cell["Position versus time:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xs[t_]\  = \ x[t] /. sol[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) - \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\)\ C[
          1] + \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) + \@\(\[Gamma]\^2 \
- 4\ \[Omega]\_0\%2\))\)\)\ C[
          2] - \(4\ \((\(-a\_0\)\ \[Omega]\^2\ Cos[t\ \[Omega]] + a\_0\ \
\[Omega]\_0\%2\ Cos[t\ \[Omega]] + a\_0\ \[Gamma]\ \[Omega]\ Sin[t\ \
\[Omega]])\)\)\/\(\((\[Gamma]\^2 + 2\ \[Omega]\^2 - 2\ \[Omega]\_0\%2 + \
\[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \
\[Omega]\^2 + 2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\)\)], "Output"]
}, Open  ]],

Cell["Velocity versus time", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vs[t_]\  = \ \(x'\)[t] /. sol[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(1\/2\ \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) - \@\(\[Gamma]\^2 - \
4\ \[Omega]\_0\%2\))\)\)\ \((\(-\[Gamma]\) - \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\
\%2\))\)\ C[1] + 
      1\/2\ \[ExponentialE]\^\(1\/2\ t\ \((\(-\[Gamma]\) + \@\(\[Gamma]\^2 - \
4\ \[Omega]\_0\%2\))\)\)\ \((\(-\[Gamma]\) + \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\
\%2\))\)\ C[
          2] - \(4\ \((a\_0\ \[Gamma]\ \[Omega]\^2\ Cos[t\ \[Omega]] + a\_0\ \
\[Omega]\^3\ Sin[t\ \[Omega]] - a\_0\ \[Omega]\ \[Omega]\_0\%2\ Sin[t\ \
\[Omega]])\)\)\/\(\((\[Gamma]\^2 + 2\ \[Omega]\^2 - 2\ \[Omega]\_0\%2 + \
\[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \
\[Omega]\^2 + 2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\)\)], "Output"]
}, Open  ]],

Cell["The position and velocity at t=0", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(xs[0]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(-\(\(4\ \((\(-a\_0\)\ \[Omega]\^2 + 
                  a\_0\ \[Omega]\_0\%2)\)\)\/\(\((\[Gamma]\^2 + 
                  2\ \[Omega]\^2 - 
                  2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \[Omega]\^2 + 
                  2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\))\)\)\)\) + C[1] + C[2]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(vs[0]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(4\ a\_0\ \[Gamma]\ \[Omega]\^2\)\/\(\((\[Gamma]\^2 + 
                  2\ \[Omega]\^2 - 
                  2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \[Omega]\^2 + 
                  2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\))\)\)\)\) + 
      1\/2\ \((\(-\[Gamma]\) - \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\ C[
          1] + 1\/2\ \((\(-\[Gamma]\) + \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\ C[2]\)], "Output"]
}, Open  ]],

Cell["\<\
Here we plan to substitute the constants C[1] and C[2] by original \
position/velocity\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solc\  = \ 
      Solve[{xs[0]\  \[Equal] \ x\_0, vs[0]\  \[Equal] \ v\_0}, {C[1], 
          C[2]}]\)], "Input"],

Cell[BoxData[
    \({{C[
            1] \[Rule] \(-\(\(\(-4\)\ a\_0\ \[Omega]\^2 - 
                    4\ x\_0\ \[Gamma]\^2\ \[Omega]\^2 - 
                    4\ x\_0\ \[Omega]\^4 + 4\ a\_0\ \[Omega]\_0\%2 + 
                    8\ x\_0\ \[Omega]\^2\ \[Omega]\_0\%2 - 
                    4\ x\_0\ \[Omega]\_0\%4\)\/\(4\ \[Gamma]\^2\ \[Omega]\^2 \
+ 4\ \[Omega]\^4 - 8\ \[Omega]\^2\ \[Omega]\_0\%2 + 
                    4\ \[Omega]\_0\%4\)\)\) + \((8\ a\_0\ \[Gamma]\^3\ \
\[Omega]\^4 - 16\ v\_0\ \[Gamma]\^4\ \[Omega]\^4 - 
                  8\ x\_0\ \[Gamma]\^5\ \[Omega]\^4 + 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^6 - 
                  32\ v\_0\ \[Gamma]\^2\ \[Omega]\^6 - 
                  16\ x\_0\ \[Gamma]\^3\ \[Omega]\^6 - 
                  16\ v\_0\ \[Omega]\^8 - 8\ x\_0\ \[Gamma]\ \[Omega]\^8 + 
                  8\ a\_0\ \[Gamma]\^3\ \[Omega]\^2\ \[Omega]\_0\%2 - 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  64\ v\_0\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  32\ x\_0\ \[Gamma]\^3\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  64\ v\_0\ \[Omega]\^6\ \[Omega]\_0\%2 + 
                  32\ x\_0\ \[Gamma]\ \[Omega]\^6\ \[Omega]\_0\%2 - 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  32\ v\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  16\ x\_0\ \[Gamma]\^3\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  96\ v\_0\ \[Omega]\^4\ \[Omega]\_0\%4 - 
                  48\ x\_0\ \[Gamma]\ \[Omega]\^4\ \[Omega]\_0\%4 + 
                  8\ a\_0\ \[Gamma]\ \[Omega]\_0\%6 + 
                  64\ v\_0\ \[Omega]\^2\ \[Omega]\_0\%6 + 
                  32\ x\_0\ \[Gamma]\ \[Omega]\^2\ \[Omega]\_0\%6 - 
                  16\ v\_0\ \[Omega]\_0\%8 - 
                  8\ x\_0\ \[Gamma]\ \[Omega]\_0\%8 - 
                  8\ a\_0\ \[Gamma]\^2\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Gamma]\^4\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ a\_0\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) \
- 16\ x\_0\ \[Gamma]\^2\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Omega]\^8\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) \
+ 8\ a\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  24\ a\_0\ \[Omega]\^4\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2\ \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Omega]\^6\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  24\ a\_0\ \[Omega]\^2\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  16\ x\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4\ \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  48\ x\_0\ \[Omega]\^4\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  8\ a\_0\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Omega]\^2\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Omega]\_0\%8\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)/\((16\ \[Gamma]\^4\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ \[Gamma]\^2\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\) + 16\ \[Omega]\^8\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  64\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2\ \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  64\ \[Omega]\^6\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4\ \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + 
                  96\ \[Omega]\^4\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  64\ \[Omega]\^2\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  16\ \[Omega]\_0\%8\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\), 
        C[2] \[Rule] \(-\(\((8\ a\_0\ \[Gamma]\^3\ \[Omega]\^4 - 
                  16\ v\_0\ \[Gamma]\^4\ \[Omega]\^4 - 
                  8\ x\_0\ \[Gamma]\^5\ \[Omega]\^4 + 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^6 - 
                  32\ v\_0\ \[Gamma]\^2\ \[Omega]\^6 - 
                  16\ x\_0\ \[Gamma]\^3\ \[Omega]\^6 - 
                  16\ v\_0\ \[Omega]\^8 - 8\ x\_0\ \[Gamma]\ \[Omega]\^8 + 
                  8\ a\_0\ \[Gamma]\^3\ \[Omega]\^2\ \[Omega]\_0\%2 - 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  64\ v\_0\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  32\ x\_0\ \[Gamma]\^3\ \[Omega]\^4\ \[Omega]\_0\%2 + 
                  64\ v\_0\ \[Omega]\^6\ \[Omega]\_0\%2 + 
                  32\ x\_0\ \[Gamma]\ \[Omega]\^6\ \[Omega]\_0\%2 - 
                  8\ a\_0\ \[Gamma]\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  32\ v\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  16\ x\_0\ \[Gamma]\^3\ \[Omega]\^2\ \[Omega]\_0\%4 - 
                  96\ v\_0\ \[Omega]\^4\ \[Omega]\_0\%4 - 
                  48\ x\_0\ \[Gamma]\ \[Omega]\^4\ \[Omega]\_0\%4 + 
                  8\ a\_0\ \[Gamma]\ \[Omega]\_0\%6 + 
                  64\ v\_0\ \[Omega]\^2\ \[Omega]\_0\%6 + 
                  32\ x\_0\ \[Gamma]\ \[Omega]\^2\ \[Omega]\_0\%6 - 
                  16\ v\_0\ \[Omega]\_0\%8 - 
                  8\ x\_0\ \[Gamma]\ \[Omega]\_0\%8 - 
                  8\ a\_0\ \[Gamma]\^2\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Gamma]\^4\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ a\_0\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) \
- 16\ x\_0\ \[Gamma]\^2\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Omega]\^8\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) \
+ 8\ a\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  24\ a\_0\ \[Omega]\^4\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2\ \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Omega]\^6\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  24\ a\_0\ \[Omega]\^2\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  16\ x\_0\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4\ \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  48\ x\_0\ \[Omega]\^4\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  8\ a\_0\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ x\_0\ \[Omega]\^2\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  8\ x\_0\ \[Omega]\_0\%8\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)/\((16\ \[Gamma]\^4\ \[Omega]\^4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ \[Gamma]\^2\ \[Omega]\^6\ \@\(\[Gamma]\^2 - 4\ \[Omega]\
\_0\%2\) + 16\ \[Omega]\^8\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  64\ \[Gamma]\^2\ \[Omega]\^4\ \[Omega]\_0\%2\ \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) - 
                  64\ \[Omega]\^6\ \[Omega]\_0\%2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  32\ \[Gamma]\^2\ \[Omega]\^2\ \[Omega]\_0\%4\ \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + 
                  96\ \[Omega]\^4\ \[Omega]\_0\%4\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) - 
                  64\ \[Omega]\^2\ \[Omega]\_0\%6\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\) + 
                  16\ \[Omega]\_0\%8\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\))\)\)\)}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(C[1] /. solc[\([1, 1]\)] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(\((a\_0\ \((\((\[Omega] - \[Omega]\_0)\)\ \((\[Omega] + \[Omega]\_0)\)\ \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + \[Gamma]\ \((\[Omega]\^2 + \
\[Omega]\_0\%2)\))\) - \((\[Gamma]\^2\ \[Omega]\^2 + \((\[Omega]\^2 - \
\[Omega]\_0\%2)\)\^2)\)\ \((2\ v\_0 + 
                x\_0\ \((\[Gamma] - \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\))\
\))\)/\((2\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\ \((\[Gamma]\^2\ \
\[Omega]\^2 + \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\))\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(C[2]\  /. solc[\([1, 2]\)] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(\((\(-a\_0\)\ \((\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\ \
\((\(-\[Omega]\^2\) + \[Omega]\_0\%2)\) + \[Gamma]\ \((\[Omega]\^2 + \[Omega]\
\_0\%2)\))\) + \((\[Gamma]\^2\ \[Omega]\^2 + \((\[Omega]\^2 - \[Omega]\_0\%2)\
\)\^2)\)\ \((2\ v\_0 + 
                x\_0\ \((\[Gamma] + \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\))\
\))\)/\((2\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\ \((\[Gamma]\^2\ \
\[Omega]\^2 + \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\))\)\)], "Output"]
}, Open  ]],

Cell["\<\
The final expression that gives the non-oscillatory solution in \
terms of the original velocity and position: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xno[t_]\  = \ xs[t] /. \ solc // FullSimplify\)], "Input"],

Cell[BoxData[
    \({\((\[ExponentialE]\^\(\(-\(1\/2\)\)\ t\ \((\[Gamma] + \@\(\[Gamma]\^2 \
- 4\ \[Omega]\_0\%2\))\)\)\ \((a\_0\ \((\(-\((1 + \[ExponentialE]\^\(t\ \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\))\)\)\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\
\)\ \((\(-\[Omega]\^2\) + \[Omega]\_0\%2)\) - \((\(-1\) + \
\[ExponentialE]\^\(t\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\))\)\ \[Gamma]\ \
\((\[Omega]\^2 + \[Omega]\_0\%2)\))\) + \((\[Gamma]\^2\ \[Omega]\^2 + \((\
\[Omega] - \[Omega]\_0)\)\^2\ \((\[Omega] + \[Omega]\_0)\)\^2)\)\ \((2\ \
\((\(-1\) + \[ExponentialE]\^\(t\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\))\)\ \
v\_0 - x\_0\ \[Gamma] + 
                      x\_0\ \((\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\) + \
\[ExponentialE]\^\(t\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\)\ \((\[Gamma] + \
\@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\))\))\) + 
                2\ a\_0\ \[ExponentialE]\^\(1\/2\ t\ \((\[Gamma] + \@\(\
\[Gamma]\^2 - 4\ \[Omega]\_0\%2\))\)\)\ \@\(\[Gamma]\^2 - 4\ \[Omega]\_0\%2\)\
\ \((\((\(-\[Omega]\^2\) + \[Omega]\_0\%2)\)\ Cos[
                          t\ \[Omega]] + \[Gamma]\ \[Omega]\ Sin[
                          t\ \[Omega]])\))\))\)/\((2\ \@\(\[Gamma]\^2 - 4\ \
\[Omega]\_0\%2\)\ \((\[Gamma]\^2\ \[Omega]\^2 + \((\[Omega] - \
\[Omega]\_0)\)\^2\ \((\[Omega] + \[Omega]\_0)\)\^2)\))\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We put the oscillatory solution by hand. We assume ",
  Cell[BoxData[
      \(\(-\[Gamma]\^2\) + 4\ \[Omega]\^2\)]],
  ">0:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(xos[
        t_]\  = \ \[ExponentialE]\^\(\(-\(1\/2\)\)\(\ \)\(t\)\(\ \ \)\(\
\[Gamma]\)\(\ \)\)\ Sin[
            t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\^2\)]\ \ c1\  + \
\[ExponentialE]\^\(\(-\(1\/2\)\)\(\ \)\(t\)\(\ \ \)\(\[Gamma]\)\(\ \)\)\ Cos[
            t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\^2\)]\ c2 - \(4\ \((a\_0\
\ \[Omega]\_0\^2\ Cos[t\ \[Omega]] - a\_0\ \[Omega]\^2\ Cos[t\ \[Omega]] + \
a\_0\ \[Gamma]\ \[Omega]\ Sin[t\ \[Omega]])\)\)\/\(\((\(-\[Gamma]\^2\) + 2\ \
\[Omega]\_0\^2 + \[Gamma]\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\^2\) - 2\ \
\[Omega]\^2)\)\ \((\[Gamma]\^2 - 2\ \[Omega]\_0\^2 + \[Gamma]\ \
\@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\^2\) + 2\ \[Omega]\^2)\)\)\)\)\)], \
"Input"],

Cell[BoxData[
    \(c2\ \[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ Cos[
          t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\)] - \(4\ \((\(-a\_0\)\ \
\[Omega]\^2\ Cos[t\ \[Omega]] + a\_0\ \[Omega]\_0\%2\ Cos[t\ \[Omega]] + a\_0\
\ \[Gamma]\ \[Omega]\ Sin[t\ \[Omega]])\)\)\/\(\((\[Gamma]\^2 + 2\ \
\[Omega]\^2 - 2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\(-\[Gamma]\^2\) + 4\ \
\[Omega]\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \[Omega]\^2 + 2\ \[Omega]\_0\%2 \
+ \[Gamma]\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\))\)\) + 
      c1\ \[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ Sin[
          t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\)]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(solc2\  = \ 
      Solve[{xos[0] \[Equal] \ x\_0, \(xos'\)[0] \[Equal] v\_0}, {c1, c2}] // 
        FullSimplify\)], "Input"],

Cell[BoxData[
    \({{c1 \[Rule] \((2\ v\_0\ \((\[Gamma]\^4 + 
                      2\ \[Gamma]\^2\ \((\[Omega]\^2 - 2\ \[Omega]\_0\%2)\) + 
                      2\ \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\) + \[Gamma]\ \
\((\(-2\)\ a\_0\ \((\[Omega]\^2 + \[Omega]\_0\%2)\) + 
                      x\_0\ \((\[Gamma]\^4 + 
                            2\ \[Gamma]\^2\ \((\[Omega]\^2 - 
                                  2\ \[Omega]\_0\%2)\) + 
                            2\ \((\[Omega]\^2 - \
\[Omega]\_0\%2)\)\^2)\))\))\)/\((2\ \@\(\(-\[Gamma]\^2\) + 4\ \
\[Omega]\_0\%2\)\ \((\[Gamma]\^4 + 
                    2\ \[Gamma]\^2\ \((\[Omega]\^2 - 2\ \[Omega]\_0\%2)\) + 
                    2\ \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\))\), 
        c2 \[Rule] 
          x\_0 + \(2\ a\_0\ \((\[Omega] - \[Omega]\_0)\)\ \((\[Omega] + \
\[Omega]\_0)\)\)\/\(\[Gamma]\^4 + 2\ \((\[Omega] - \[Omega]\_0)\)\^2\ \((\
\[Omega] + \[Omega]\_0)\)\^2 + 2\ \[Gamma]\^2\ \((\[Omega]\^2 - 2\ \
\[Omega]\_0\%2)\)\)}}\)], "Output"]
}, Open  ]],

Cell["\<\
The final expression for theoscillatory solution in terms of \
initial position and velocity:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(xosc[t_]\  = \ xos[t]\  /. solc2\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(xosc\\)\\\" is similar to existing symbol \\\
\"\\!\\(xos\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \({\[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ \((x\_0 + \(2\ a\_0\ \((\
\[Omega] - \[Omega]\_0)\)\ \((\[Omega] + \[Omega]\_0)\)\)\/\(\[Gamma]\^4 + 2\ \
\((\[Omega] - \[Omega]\_0)\)\^2\ \((\[Omega] + \[Omega]\_0)\)\^2 + 2\ \
\[Gamma]\^2\ \((\[Omega]\^2 - 2\ \[Omega]\_0\%2)\)\))\)\ Cos[
            t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\)] - \(4\ \
\((\(-a\_0\)\ \[Omega]\^2\ Cos[t\ \[Omega]] + a\_0\ \[Omega]\_0\%2\ Cos[t\ \
\[Omega]] + a\_0\ \[Gamma]\ \[Omega]\ Sin[t\ \[Omega]])\)\)\/\(\((\[Gamma]\^2 \
+ 2\ \[Omega]\^2 - 2\ \[Omega]\_0\%2 + \[Gamma]\ \@\(\(-\[Gamma]\^2\) + 4\ \
\[Omega]\_0\%2\))\)\ \((\(-\[Gamma]\^2\) - 2\ \[Omega]\^2 + 2\ \[Omega]\_0\%2 \
+ \[Gamma]\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\))\)\) + \((\
\[ExponentialE]\^\(-\(\(t\ \[Gamma]\)\/2\)\)\ \((2\ v\_0\ \((\[Gamma]\^4 + 
                        2\ \[Gamma]\^2\ \((\[Omega]\^2 - 
                              2\ \[Omega]\_0\%2)\) + 
                        2\ \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\) + \
\[Gamma]\ \((\(-2\)\ a\_0\ \((\[Omega]\^2 + \[Omega]\_0\%2)\) + 
                        x\_0\ \((\[Gamma]\^4 + 
                              2\ \[Gamma]\^2\ \((\[Omega]\^2 - 
                                    2\ \[Omega]\_0\%2)\) + 
                              2\ \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\))\))\
\)\ Sin[t\ \@\(\(-\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\)])\)/\((2\ \@\(\(-\
\[Gamma]\^2\) + 4\ \[Omega]\_0\%2\)\ \((\[Gamma]\^4 + 
                  2\ \[Gamma]\^2\ \((\[Omega]\^2 - 2\ \[Omega]\_0\%2)\) + 
                  2\ \((\[Omega]\^2 - \[Omega]\_0\%2)\)\^2)\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[xosc[t] /. {x\_0 \[Rule] 5, 
            v\_0 \[Rule] 0.0, \[Omega]\_0 \[Rule] 4, \[Omega] \[Rule] 
              0.3, \[Gamma] \[Rule] 1, a\_0 \[Rule] 1}], {t, 0, 
        40}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.318975 0.888313 [
[.2619 .30648 -6 -9 ]
[.2619 .30648 6 0 ]
[.5 .30648 -6 -9 ]
[.5 .30648 6 0 ]
[.7381 .30648 -6 -9 ]
[.7381 .30648 6 0 ]
[.97619 .30648 -6 -9 ]
[.97619 .30648 6 0 ]
[.01131 .05248 -24 -4.5 ]
[.01131 .05248 0 4.5 ]
[.01131 .14131 -24 -4.5 ]
[.01131 .14131 0 4.5 ]
[.01131 .23014 -24 -4.5 ]
[.01131 .23014 0 4.5 ]
[.01131 .40781 -18 -4.5 ]
[.01131 .40781 0 4.5 ]
[.01131 .49664 -18 -4.5 ]
[.01131 .49664 0 4.5 ]
[.01131 .58547 -18 -4.5 ]
[.01131 .58547 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .31898 m
.2619 .32523 L
s
[(10)] .2619 .30648 0 1 Mshowa
.5 .31898 m
.5 .32523 L
s
[(20)] .5 .30648 0 1 Mshowa
.7381 .31898 m
.7381 .32523 L
s
[(30)] .7381 .30648 0 1 Mshowa
.97619 .31898 m
.97619 .32523 L
s
[(40)] .97619 .30648 0 1 Mshowa
.125 Mabswid
.07143 .31898 m
.07143 .32273 L
s
.11905 .31898 m
.11905 .32273 L
s
.16667 .31898 m
.16667 .32273 L
s
.21429 .31898 m
.21429 .32273 L
s
.30952 .31898 m
.30952 .32273 L
s
.35714 .31898 m
.35714 .32273 L
s
.40476 .31898 m
.40476 .32273 L
s
.45238 .31898 m
.45238 .32273 L
s
.54762 .31898 m
.54762 .32273 L
s
.59524 .31898 m
.59524 .32273 L
s
.64286 .31898 m
.64286 .32273 L
s
.69048 .31898 m
.69048 .32273 L
s
.78571 .31898 m
.78571 .32273 L
s
.83333 .31898 m
.83333 .32273 L
s
.88095 .31898 m
.88095 .32273 L
s
.92857 .31898 m
.92857 .32273 L
s
.25 Mabswid
0 .31898 m
1 .31898 L
s
.02381 .05248 m
.03006 .05248 L
s
[(-0.3)] .01131 .05248 1 0 Mshowa
.02381 .14131 m
.03006 .14131 L
s
[(-0.2)] .01131 .14131 1 0 Mshowa
.02381 .23014 m
.03006 .23014 L
s
[(-0.1)] .01131 .23014 1 0 Mshowa
.02381 .40781 m
.03006 .40781 L
s
[(0.1)] .01131 .40781 1 0 Mshowa
.02381 .49664 m
.03006 .49664 L
s
[(0.2)] .01131 .49664 1 0 Mshowa
.02381 .58547 m
.03006 .58547 L
s
[(0.3)] .01131 .58547 1 0 Mshowa
.125 Mabswid
.02381 .07025 m
.02756 .07025 L
s
.02381 .08801 m
.02756 .08801 L
s
.02381 .10578 m
.02756 .10578 L
s
.02381 .12355 m
.02756 .12355 L
s
.02381 .15908 m
.02756 .15908 L
s
.02381 .17685 m
.02756 .17685 L
s
.02381 .19461 m
.02756 .19461 L
s
.02381 .21238 m
.02756 .21238 L
s
.02381 .24791 m
.02756 .24791 L
s
.02381 .26568 m
.02756 .26568 L
s
.02381 .28344 m
.02756 .28344 L
s
.02381 .30121 m
.02756 .30121 L
s
.02381 .33674 m
.02756 .33674 L
s
.02381 .35451 m
.02756 .35451 L
s
.02381 .37227 m
.02756 .37227 L
s
.02381 .39004 m
.02756 .39004 L
s
.02381 .42557 m
.02756 .42557 L
s
.02381 .44334 m
.02756 .44334 L
s
.02381 .46111 m
.02756 .46111 L
s
.02381 .47887 m
.02756 .47887 L
s
.02381 .5144 m
.02756 .5144 L
s
.02381 .53217 m
.02756 .53217 L
s
.02381 .54994 m
.02756 .54994 L
s
.02381 .5677 m
.02756 .5677 L
s
.02381 .03472 m
.02756 .03472 L
s
.02381 .01695 m
.02756 .01695 L
s
.02381 .60324 m
.02756 .60324 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.08458 .61803 m
.08518 .39623 L
s
.08518 .39623 m
.08622 0 L
s
.09357 0 m
.09466 .35313 L
.09543 .60107 L
s
.09543 .60107 m
.09549 .61803 L
s
.10313 .61803 m
.10458 .22571 L
s
.10458 .22571 m
.10552 0 L
s
.11193 0 m
.11199 .01179 L
.11447 .54843 L
s
.11447 .54843 m
.11486 .61803 L
s
.12139 .61803 m
.12223 .47332 L
.12358 .22732 L
.1243 .10845 L
s
.1243 .10845 m
.12506 0 L
s
.12999 0 m
.13091 .11722 L
.13208 .28992 L
.13319 .45063 L
.13422 .58134 L
s
.13422 .58134 m
.13465 .61803 L
s
.13925 .61803 m
.13938 .60727 L
.14188 .31584 L
.14306 .17812 L
.14415 .07596 L
.14531 .00757 L
s
.14531 .00757 m
.14582 0 L
s
.14697 0 m
.14769 .02021 L
.14887 .09554 L
.15147 .3428 L
.15275 .45915 L
.15391 .53898 L
.15493 .57894 L
.156 .58731 L
.15707 .56145 L
.15824 .49949 L
.1607 .30595 L
.1619 .21104 L
.16301 .14105 L
.16432 .09166 L
.16501 .08237 L
.16573 .08543 L
.16691 .11662 L
.1682 .18108 L
.17087 .3551 L
.17164 .40007 L
.17237 .43554 L
.17302 .45987 L
.17373 .47707 L
.17503 .48178 L
.17568 .47129 L
.17641 .45063 L
.17768 .39552 L
.17888 .33047 L
.18008 .26303 L
.18137 .20037 L
.18259 .15936 L
.18369 .14218 L
.18485 .14618 L
.1861 .1738 L
.18728 .21679 L
.18838 .26457 L
.18966 .32162 L
.19087 .36712 L
.19212 .39889 L
.19279 .40751 L
.19351 .40992 L
.19419 .4056 L
.19483 .39611 L
.19553 .38029 L
.19628 .3583 L
.19891 .26119 L
.19955 .23871 L
.20024 .21727 L
.2015 .18909 L
.20272 .17784 L
Mistroke
.20385 .18243 L
.20492 .19884 L
.20607 .22644 L
.20814 .28773 L
.2094 .32186 L
.2106 .34528 L
.21168 .35613 L
.21285 .35576 L
.21398 .34379 L
.21524 .31987 L
.21778 .2562 L
.21892 .2306 L
.22014 .21054 L
.22129 .20117 L
.22235 .20149 L
.22363 .21255 L
.22483 .2314 L
.22709 .27611 L
.22827 .29731 L
.22952 .3134 L
.23018 .31836 L
.2309 .32077 L
.23216 .31721 L
.23335 .30569 L
.23443 .29002 L
.23688 .24849 L
.23796 .23269 L
.23914 .22052 L
.24025 .21517 L
.24128 .21592 L
.26199 .23544 L
.26447 .25728 L
.26583 .26882 L
.26709 .27672 L
.26775 .2793 L
.26846 .28072 L
.26925 .28063 L
.26996 .27907 L
.27061 .27654 L
.27131 .27277 L
.2726 .26397 L
.27511 .24527 L
.27638 .23838 L
.2771 .23588 L
.27778 .23461 L
.27898 .235 L
.28009 .23815 L
.28136 .24438 L
.28257 .25182 L
.28372 .25913 L
Mistroke
.2848 .26528 L
.28605 .27052 L
.28718 .27295 L
.28826 .27301 L
.28924 .27122 L
.29033 .26756 L
.29147 .26238 L
.29371 .25148 L
.29496 .24677 L
.29611 .24424 L
.29675 .24369 L
.29746 .24385 L
.29874 .24605 L
.30001 .25027 L
.30119 .2553 L
.30345 .26509 L
.30458 .26884 L
.30582 .27131 L
.30647 .27184 L
.30717 .27179 L
.30843 .27028 L
.30968 .26731 L
.31081 .26388 L
.3119 .26051 L
.31304 .25736 L
.3143 .25497 L
.31546 .25412 L
.31654 .2546 L
.31755 .25612 L
.31866 .25878 L
.31985 .26242 L
.32249 .27076 L
.32321 .27257 L
.32398 .27409 L
.32471 .27508 L
.32537 .27559 L
.32667 .27551 L
.3274 .27491 L
.32807 .27407 L
.33061 .26965 L
.33171 .26786 L
.33289 .26654 L
.33419 .26609 L
.3354 .26675 L
.33605 .26753 L
.33675 .26867 L
.33804 .27136 L
.34045 .27731 L
.34159 .27986 L
.34279 .28195 L
Mistroke
.3441 .28335 L
.34531 .28377 L
.34644 .28349 L
.34748 .28279 L
.34986 .28064 L
.35052 .28015 L
.35122 .27975 L
.3525 .27954 L
.35374 .28006 L
.35489 .28119 L
.35613 .28303 L
.35749 .28556 L
.35891 .28837 L
.36025 .29087 L
.36156 .29286 L
.3623 .29373 L
.36299 .29433 L
.3642 .29497 L
.36549 .2951 L
.36615 .295 L
.36687 .29481 L
.36816 .29439 L
.36891 .29419 L
.3697 .29407 L
.37038 .29407 L
.37111 .29422 L
.3718 .29451 L
.37244 .29492 L
.37365 .29605 L
.37496 .29773 L
.37637 .29992 L
.37873 .30373 L
.37994 .30544 L
.38063 .30627 L
.38127 .30693 L
.38257 .30795 L
.38382 .30853 L
.38494 .30881 L
.38614 .30894 L
.38738 .30904 L
.38854 .30923 L
.38958 .30957 L
.39071 .31018 L
.39197 .31118 L
.39335 .31266 L
.39613 .31636 L
.39869 .3197 L
.39995 .32103 L
.40111 .32201 L
.40243 .32285 L
Mistroke
.40312 .32318 L
.40386 .32348 L
.40636 .32431 L
.40765 .32482 L
.40904 .32556 L
.41056 .32669 L
.41199 .32803 L
.42214 .33779 L
.44219 .35203 L
.46329 .36483 L
.47284 .37009 L
.48304 .37426 L
.48768 .37597 L
.4926 .37796 L
.49462 .37864 L
.49679 .37921 L
.49918 .37969 L
.50141 .38008 L
.50666 .38109 L
.50925 .38163 L
.51165 .38207 L
.513 .38226 L
.51443 .38242 L
.51525 .38248 L
.51602 .38252 L
.51671 .38255 L
.51746 .38257 L
.5181 .38258 L
.5188 .38259 L
.51954 .3826 L
.52022 .3826 L
.52154 .3826 L
.52276 .3826 L
.52401 .38261 L
.52467 .38262 L
.52538 .38263 L
.52655 .38264 L
.52785 .38264 L
.52901 .38263 L
.53025 .3826 L
.53142 .38254 L
.53249 .38246 L
.53382 .38233 L
.53504 .38218 L
.53783 .38175 L
.54291 .38084 L
.54798 .37986 L
.55347 .37843 L
.56341 .37498 L
.58202 .3664 L
Mistroke
.60194 .35435 L
.623 .33922 L
.66094 .30913 L
.68207 .29291 L
.70134 .27968 L
.72153 .26831 L
.73042 .2643 L
.74023 .26068 L
.74947 .25807 L
.75453 .257 L
.75929 .25621 L
.76183 .25589 L
.7645 .25561 L
.76678 .25544 L
.76807 .25536 L
.76928 .2553 L
.76995 .25528 L
.77068 .25525 L
.77137 .25524 L
.772 .25523 L
.77321 .25522 L
.77448 .25523 L
.77514 .25524 L
.77585 .25525 L
.77713 .2553 L
.77791 .25533 L
.77865 .25537 L
.78005 .25545 L
.78264 .25566 L
.78508 .25592 L
.78965 .25657 L
.79456 .25749 L
.79987 .25876 L
.80946 .26172 L
.81827 .26518 L
.83711 .27474 L
.85778 .28805 L
.89823 .31919 L
.93717 .3492 L
.97619 .37212 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{489.125, 302.312},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009S0001NB000`400?l00000o`00003oo`3IfMWo
0=WIfFD0fMWI003o0=WIfOl0fMWII@3IfMT00?l0fMWIo`3IfMUU0=WIf@00o`3IfMWo0=WIfFD0fMWI
003o0=WIfOl0fMWII@3IfMT00?l0fMWIo`3IfMUU0=WIf@00o`3IfMWo0=WIfFD0fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@800000o`3IfMWf
0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203I
fMT200000?l0fMWImP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003I
fMT0fMWI000000P0fMWI0P00003o0=WIfOH0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT010000000fMWI0=WIf@0000080=WIf@800000o`3IfMWf0=WIf@009@3IfMT00`000000fMWI
0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT200000?l0fMWImP3IfMT002D0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o
0=WIfOH0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00
00080=WIf@030000003IfMT000000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@009@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0000003o0=WIfOD0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000
fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWIm@3IfMT002D0fMWI0`00000Q0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfOD0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003I
fMT000000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003I
fMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI0=WI
f@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfOD0
fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT000000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@009@3IfMT00`00
0000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000
003o0=WIfOD0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WI
f@0000080=WIf@030000003IfMT000000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@00
9@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0000003o0=WIfOD0fMWI000U0=WIf@<000008@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI
000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfOD0fMWI000U
0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@04
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT000000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000
003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI
0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00003o
0=WIfOD0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00
00070=WIf@040000003IfMT0fMWI00000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WI
f@00203IfMT4000000D0fMWI0P0000040=WIf@@000002P3IfMT00`000000fMWI0=WIf@0Q0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00003o0=WIfOD0fMWI0007
0=WIf@8000000P3IfMT2000000@0fMWI0P0000080=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT0
0000o`3IfMWe0=WIf@001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3I
fMT000001`3IfMT010000000fMWI0=WIf@00003o0=WIfOD0fMWI00070=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@070=WIf@D000007`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WIf@0000@0
fMWI00000000000000000`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00X0fMWI
0P00000:0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000070=WI
f@040000003IfMT0fMWI00000?l0fMWIm@3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WIf@001`3I
fMT200000080fMWI0P00000>0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WI
f@00203IfMT4000000`0fMWI0`00000:0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WIf@009@3IfMT0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000
003IfMT0fMWI00000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00003o0=WIfOD0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@0
00000=WIf@3IfMT00000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI00000?l0fMWIm@3IfMT002D0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
10000000fMWI0=WIf@00003o0=WIfOD0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WIf@00
9@3IfMT300000240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WI
f@3IfMT00000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI00000?l0fMWIm@3IfMT002D0fMWI00<0
00000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000
fMWI0=WIf@00003o0=WIfOD0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000o`3IfMWe0=WIf@009@3IfMT0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000
003IfMT0fMWI00000?l0fMWIm@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00003o0=WIfOD0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@0
00000=WIf@3IfMT00000o`3IfMWe0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WI
f@3IfMT0o`3IfMWY0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT0o`3I
fMWY0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT0o`3IfMWY0=WIf@00
9@3IfMT300000240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WI
f@3IfMT00000203IfMT200000?l0fMWIj`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@800000
o`3IfMW[0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0
fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfN/0fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@00000
0=WIf@3IfMT00000203IfMT200000?l0fMWIj`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@80
0000o`3IfMW[0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfN/0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@0
00000=WIf@3IfMT00000203IfMT200000?l0fMWIj`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WI
f@800000o`3IfMW[0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3I
fMWZ0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWZ0=WIf@00
9@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWZ0=WIf@009@3IfMT30000
0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000
203IfMT00`000000fMWI0000003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0000003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000
003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfNX0
fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WI
fNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o
0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000
003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0000003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000
fMWI0000003o0=WIfNX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0000003o0=WIfNX0fMWI000U0=WIf@<000008@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0
00000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003I
fMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@04
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000
003IfMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WI
f@030000003IfMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@000008
0=WIf@030000003IfMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00
00080=WIf@030000003IfMT000000?l0fMWIjP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WI
f@0000080=WIf@030000003IfMT000000?l0fMWIjP3IfMT000P0fMWI100000050=WIf@800000103I
fMT6000000P0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0
fMWIjP3IfMT000L0fMWI0P0000020=WIf@800000103IfMT2000000D0fMWI00D000000=WIf@3IfMT0
fMWI000000080=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o
0=WIfNX0fMWI00070=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT20000
00X0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWIjP3I
fMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0
fMWI00L0fMWI1@00000O0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@0000002@3IfMT00`000000fMWI
0=WIf@3o0=WIfMh0fMWI0000103IfMT000000000000000030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3I
fMT00000203IfMT00`000000fMWI000000090=WIf@030000003IfMT0fMWI0?l0fMWIgP3IfMT000L0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0000000T0fMWI00<00000
0=WIf@3IfMT0o`3IfMWN0=WIf@001`3IfMT200000080fMWI0P00000:0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@0000002@3IfMT00`000000fMWI0=WIf@3o0=WIfMh0fMWI00080=WIf@@00000303IfMT4
000000T0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI000000P0
fMWI00<000000=WIf@3IfMT0o`3IfMWN0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI0000
00P0fMWI00@000000=WIf@3IfMT000001`3IfMT200000?l0fMWIh03IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
10000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI000000L0fMWI0P00003o0=WIfN00fMWI
000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT010000000fMWI0=WIf@0000070=WI
f@800000o`3IfMWP0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI00@00000
0=WIf@3IfMT000001`3IfMT200000?l0fMWIh03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WI
f@0000080=WIf@040000003IfMT0fMWI000000L0fMWI0P00003o0=WIfN00fMWI000U0=WIf@<00000
8@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT000001`3IfMT200000?l0fMWIh03IfMT0
02D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000
1`3IfMT00`000000fMWI0000003o0=WIfMl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0
fMWI000000070=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWO0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00
00070=WIf@030000003IfMT000000?l0fMWIg`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000L0fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WIfMl0
fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@04
0000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWO0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@000007
0=WIf@030000003IfMT000000?l0fMWIg`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@00
0000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000
003o0=WIfMl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000
00070=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWO0=WIf@009@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI
0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIg`3IfMT002D0fMWI0`00000Q0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WI
f@000000o`3IfMWO0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@0000002@3IfMT0
0`000000fMWI0=WIf@3o0=WIfM<0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WI
f@0000090=WIf@030000003IfMT0fMWI0?l0fMWId`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@04
0000003IfMT0fMWI000000T0fMWI0P00003o0=WIfM@0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
10000000fMWI0=WIf@0000090=WIf@800000o`3IfMWD0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@04
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfM@0fMWI000U0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWIe03IfMT0
02D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000
o`3IfMWD0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0000003o0=WIfM@0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@00
00080=WIf@030000003IfMT000000?l0fMWIe03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000
003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMWD0=WIf@009@3IfMT300000240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWIe03IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0000003o0=WIfM@0fMWI
000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WI
f@000000o`3IfMWD0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI0000
00070=WIf@030000003IfMT000000?l0fMWIe03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000
003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI000000090=WIf@030000003IfMT0fMWI0?l0
fMWIb03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
10000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI0?l0fMWIb03IfMT002D0fMWI00<00000
0=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000090=WI
f@030000003IfMT0fMWI0?l0fMWIb03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWI
b@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01000
0000fMWI0=WIf@0000080=WIf@030000003IfMT000000?l0fMWIb@3IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT010000000fMWI0=WIf@0000080=WIf@03
0000003IfMT000000?l0fMWIb@3IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@000000o`3IfMW90=WIf@009@3IfMT0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT00`000000fMWI0000003o0=WIfLT0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000
003IfMT0000000T0fMWI00<000000=WIf@3IfMT0o`3IfMVm0=WIf@009@3IfMT00`000000fMWI0=WI
f@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT0
0`000000fMWI000000090=WIf@800000o`3IfMVn0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000
fMWI000000080=WIf@040000003IfMT0fMWI00000?l0fMWI_@3IfMT002D0fMWI00<000000=WIf@3I
fMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00@000000=WIf@3IfMT00000203IfMT01@000000fMWI0=WIf@3IfMT000000?l0fMWI_03IfMT002D0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0o`3IfMVi0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3o0=WIfKP0fMWI
00080=WIf@@000001@3IfMT2000000D0fMWI1@0000080=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@040=WIf@800000o`3IfMVh0=WIf@001`3IfMT2
00000080fMWI0P0000040=WIf@8000001`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0
fMWI0?l0fMWI]@3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMVd0=WIf@001`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0203IfMT5000001l0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000
003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0?l0
fMWI/`3IfMT000040=WIf@0000000000000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0
fMWI000000070=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0o`3IfMVb0=WIf@00
1`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIY`3IfMT000L0fMWI0P00
00020=WIf@8000003@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI0P00
003o0=WIfJP0fMWI00080=WIf@@000003@3IfMT2000000X0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000
003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WI
f@3IfMT0fMWI000000070=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0000003o0=WIfJP0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@000000o`3IfMVX0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@050=WIf@040000003IfMT0fMWI0000
0?l0fMWIY`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
0?l0fMWIY`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT00000
00P0fMWI00<000000=WIf@3IfMT0o`3IfMVL0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI
0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@040=WIf@05
0000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0000003o0=WIfId0fMWI000U0=WIf@<0
00008@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00d0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@000000o`3IfMVM0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3I
fMT000000?l0fMWIW03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000003o
0=WIfI`0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000o`3IfMVL0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00@0fMWI0`00003o0=WIf@/0fMWI0`0000240=WIf@009@3IfMT00`000000fMWI0=WIf@0Q
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT03@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@00
0000o`3IfMT30=WIf@P000000P3IfMT:000007/0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0103IfMT01000
0000fMWI0=WIf@00003k0=WIf@H00000503IfMT3000007P0fMWI000U0=WIf@030000003IfMT0fMWI
0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT000000?P0fMWI0`00000M0=WIf@@00000M03I
fMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00h0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT0lP3IfMT3000002@0fMWI1@00001_0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT03`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`00
0000fMWI0=WIf@3`0=WIf@800000;03IfMT2000006d0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000
003IfMT0fMWI0>d0fMWI0`00000`0=WIf@800000J`3IfMT002D0fMWI0`00000Q0=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT03`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00@000000=WIf@3I
fMT00000203IfMT010000000fMWI0=WIf@0000050=WIf@030000003IfMT0fMWI00@0fMWI0`00003S
0=WIf@<00000=@3IfMT2000006T0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0?0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0000
00080=WIf@040000003IfMT0fMWI000000H0fMWI00<000000=WIf@3IfMT00`3IfMT010000000fMWI
00000000003P0=WIf@800000>P3IfMT2000006L0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WI
f@000000203IfMT00`000000fMWI000000070=WIf@030000003IfMT0fMWI0080fMWI00D000000=WI
f@3IfMT0fMWI0000003N0=WIf@800000?P3IfMT2000006D0fMWI000U0=WIf@030000003IfMT0fMWI
0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0?0=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@000000203IfMT2000000P0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000
003IfMT0fMWI0=/0fMWI00<000000=WIf@3IfMT0@03IfMT2000006<0fMWI000U0=WIf@030000003I
fMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0000000P0fMWI
0P00000D0=WIf@040000003IfMT0fMWI000000D0fMWI00<000000=WIf@3IfMT0f03IfMT2000004D0
fMWI0P00001Q0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0000000N0=WIf@<000001P3IfMT00`000000fMWI0=WIf@3F0=WIf@80
0000B@3IfMT00`000000fMWI0=WIf@1N0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0000000X0=WIf@030000003IfMT0fMWI0=@0
fMWI00<000000=WIf@3IfMT0BP3IfMT2000005h0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@800000:@3IfMT00`000000fMWI0=WIf@3B0=WIf@80
0000C`3IfMT00`000000fMWI0=WIf@1K0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WI
f@0000004`3IfMT2000002T0fMWI00<000000=WIf@3IfMT00P3IfMT400000</0fMWI00<000000=WI
f@3IfMT0D03IfMT2000005/0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000000o
0=WIf@040000003IfMT0fMWI000000<0fMWI00<000000=WIf@3IfMT0a`3IfMT2000005D0fMWI00<0
00000=WIf@3IfMT0F03IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000@03IfMT3000000@0fMWI
00<000000=WIf@3IfMT0a@3IfMT00`000000fMWI0=WIf@1F0=WIf@800000F03IfMT002D0fMWI00<0
00000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
0`3IfMT01@000000fMWI0=WIf@3IfMT0000004P0fMWI00<000000=WIf@3IfMT0`P3IfMT2000005/0
fMWI00<000000=WIf@3IfMT0E@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000190=WI
f@030000003IfMT0fMWI0<00fMWI00<000000=WIf@3IfMT0G03IfMT2000005D0fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT00000
00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00@0fMWI00@000000=WIf@3IfMT00000B@3IfMT00`000000fMWI0=WIf@2n0=WIf@800000H@3IfMT0
0`000000fMWI0=WIf@1B0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000X0fMWI1@00
00030=WIf@@00000<`3IfMT00`000000fMWI0=WIf@180=WIf@H000000`3IfMT4000006P0fMWI00<0
00000=WIf@3IfMT0503IfMT4000000D0fMWI100000110=WIf@030000003IfMT0fMWI03d0fMWI0`00
00040=WIf@@000002@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@03
0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00000<0=WIf@030000
003IfMT0fMWI0080fMWI0P0000020=WIf@800000<`3IfMT00`000000fMWI0=WIf@180=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT200000080fMWI0P00001U0=WIf@8000006`3IfMT010000000
fMWI0=WIf@3IfMT200000080fMWI0P0000110=WIf@800000?P3IfMT00`000000fMWI0=WIf@020=WI
f@8000000P3IfMT2000000P0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT00000303IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0<@3IfMT200000080fMWI0`0000150=WIf@800000103IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT06`3IfMT01@000000fMWI0=WIf@3IfMT0
000000@0fMWI00<000000=WIf@3IfMT0@@3IfMT00`000000fMWI0=WIf@0h0=WIf@D000000`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI000U0=WIf@030000003IfMT0fMWI
0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00@0fMWI00@000000=WIf@3IfMT00000303IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT0<`3IfMT200000080fMWI0P0000160=WIf@050000003IfMT0
fMWI0=WIf@000000103IfMT00`000000fMWI0=WIf@1Q0=WIf@030000003IfMT0fMWI01`0fMWI00D0
00000=WIf@3IfMT0fMWI000000040=WIf@030000003IfMT0fMWI0480fMWI00<000000=WIf@3IfMT0
=`3IfMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT01P3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00000<0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0i0=WIf@03
0000003IfMT0fMWI04@0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@1O0=WI
f@8000007@3IfMT2000000@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@130=WI
f@800000>03IfMT00`000000fMWI000000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT01P3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00000<0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0j0=WI
f@030000003IfMT0fMWI04<0fMWI00@000000=WIf@3IfMT00000103IfMT00`000000fMWI0=WIf@1N
0=WIf@030000003IfMT0fMWI01l0fMWI00D000000=WIf@3IfMT0fMWI000000040=WIf@030000003I
fMT0fMWI04D0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI000000040=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0
fMWI000000`0fMWI00<000000=WIf@3IfMT00P3IfMT200000080fMWI0P00000l0=WIf@030000003I
fMT0fMWI03h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0200000080fMWI0P00
001O0=WIf@030000003IfMT0fMWI0200fMWI00@000000=WIf@3IfMT0fMWI0P0000020=WIf@800000
B03IfMT00`000000fMWI0=WIf@0e0=WIf@800000103IfMT200000080fMWI0P0000080=WIf@009@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000/0fMWI0P0000050=WIf@@00000
?P3IfMT00`000000fMWI0=WIf@0n0=WIf@@00000103IfMT4000005h0fMWI0P00000P0=WIf@<00000
1@3IfMT4000004X0fMWI0P00000f0=WIf@030000003IfMT0fMWI00<0fMWI100000090=WIf@009@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI
000000070=WIf@040000003IfMT0fMWI000005@0fMWI00<000000=WIf@3IfMT0Y`3IfMT00`000000
fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI04H0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0000005D0
fMWI00<000000=WIf@3IfMT0Y@3IfMT00`000000fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI04D0
fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI
0=WIf@0000080=WIf@030000003IfMT0000005H0fMWI00<000000=WIf@3IfMT0XP3IfMT2000007h0
fMWI0P0000150=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI
00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000001G0=WIf@D00000WP3IfMT00`000000
fMWI0=WIf@200=WIf@030000003IfMT0fMWI0480fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0000005/0
fMWI0P00002L0=WIf@030000003IfMT0fMWI0880fMWI00<000000=WIf@3IfMT0@@3IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000P0
fMWI0P00001N0=WIf@030000003IfMT0fMWI09L0fMWI0P0000260=WIf@800000@@3IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000P0
fMWI0P00001O0=WIf@030000003IfMT0fMWI09D0fMWI00<000000=WIf@3IfMT0R03IfMT00`000000
fMWI0=WIf@0n0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI
00@000000=WIf@3IfMT00000203IfMT2000005l0fMWI00<000000=WIf@3IfMT0U03IfMT00`000000
fMWI0=WIf@2:0=WIf@030000003IfMT0fMWI03d0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000080=WIf@800000H03IfMT00`000000
fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI08`0fMWI0P00000m0=WIf@005`3IfMWo00000?l00000
CP00000002D0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@060000003I
fMT0fMWI0000003IfMT00000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@000000103IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT06@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WIf@0000006`3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT06@3I
fMT00`000000fMWI0=WIf@0I0=WIf@040000003IfMT00000000001P0fMWI00<000000=WIf@3IfMT0
6@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0
6@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0
6@3IfMT00`000000fMWI0=WIf@0<0=WIf@009@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003I
fMT0fMWI00D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI00<0fMWI00H000000=WIf@3IfMT000000=WIf@0000040=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@070000003IfMT0fMWI0=WI
f@000000fMWI000000040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000001/0fMWI00<000000=WIf@3IfMT06@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01H0fMWI0`00000K0=WIf@030000003I
fMT0fMWI01T0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003I
fMT0fMWI01T0fMWI0P00000J0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT06@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT02@3I
fMT2000000h0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0<0=WIf@009@3IfMT0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000006`3I
fMT00`000000fMWI0=WIf@1@0=WIf@<00000=@3IfMT00`000000fMWI0=WIf@1A0=WIf@030000003I
fMT0fMWI03D0fMWI00<000000=WIf@3IfMT0G`3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003I
fMT0fMWI00`0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@00000K0=WIf@030000003IfMT0fMWI05<0fMWI0P00000c0=WIf@030000003I
fMT0fMWI0500fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@1P0=WIf@030000003I
fMT0fMWI02H0fMWI00<000000=WIf@3IfMT0303IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000007<0fMWI00<000000=WIf@3IfMT0P@3I
fMT2000009d0fMWI0P00000e0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00@0fMWI00@000000=WIf@3IfMT00000M03IfMT00`000000fMWI0=WIf@1o0=WIf@030000003I
fMT0fMWI09l0fMWI00<000000=WIf@3IfMT0<P3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0000007H0fMWI00<000000=WIf@3IfMT0O@3IfMT0
0`000000fMWI0=WIf@2Q0=WIf@030000003IfMT0fMWI0340fMWI000U0=WIf@030000003IfMT0fMWI
0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0000001g0=WIf@030000003IfMT0fMWI
07/0fMWI00<000000=WIf@3IfMT0X`3IfMT00`000000fMWI0=WIf@0`0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@000000N03IfMT00`000000fMWI0=WIf@1i0=WI
f@030000003IfMT0fMWI0:D0fMWI0P00000`0=WIf@009@3IfMT300000240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`00
0000fMWI0000001i0=WIf@030000003IfMT0fMWI07H0fMWI0P00002Z0=WIf@030000003IfMT0fMWI
02d0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0000001j0=WI
f@030000003IfMT0fMWI07@0fMWI00<000000=WIf@3IfMT0Z`3IfMT00`000000fMWI0=WIf@0/0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@000000N`3IfMT20000
07<0fMWI00<000000=WIf@3IfMT0[@3IfMT00`000000fMWI0=WIf@0[0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00<000000=WIf@000000O@3IfMT00`000000fMWI0=WIf@1^0=WI
f@800000/@3IfMT2000002/0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`00
0000fMWI0000001n0=WIf@030000003IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0/`3IfMT00`00
0000fMWI0=WIf@0X0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT00000
07l0fMWI0P00001Z0=WIf@800000]`3IfMT00`000000fMWI0=WIf@0W0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@0000070=WIf@030000003IfMT000000840fMWI00<000000=WIf@3IfMT0IP3IfMT00`00
0000fMWI0=WIf@2h0=WIf@8000009`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`00
0000fMWI000000220=WIf@030000003IfMT0fMWI06@0fMWI00<000000=WIf@3IfMT0^`3IfMT00`00
0000fMWI0=WIf@0T0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT00000
08<0fMWI0P00001R0=WIf@800000_`3IfMT00`000000fMWI0=WIf@0S0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@0000080=WIf@800000Q@3IfMT00`000000fMWI0=WIf@1N0=WIf@030000003IfMT0fMWI
0<00fMWI0P00000S0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000080=WIf@800000QP3IfMT20000
05`0fMWI0P0000350=WIf@8000008@3IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000080=WIf@800000R03IfMT20000
05T0fMWI00<000000=WIf@3IfMT0a`3IfMT2000001l0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0000
00P0fMWI0P00002:0=WIf@030000003IfMT0fMWI05@0fMWI0P00003<0=WIf@030000003IfMT0fMWI
01`0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI000009D0fMWI0P00001C0=WIf@030000003IfMT0fMWI
0<d0fMWI0P00000L0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00002G0=WIf@030000003IfMT0fMWI
04h0fMWI0P00003B0=WIf@8000006P3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT00000V03IfMT20000
04`0fMWI0P00003F0=WIf@800000603IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000VP3IfMT2000004T0fMWI00<00000
0=WIf@3IfMT0f03IfMT2000001H0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WI
f@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000009`0fMWI00<000000=WIf@3IfMT0A03I
fMT200000=d0fMWI00<000000=WIf@3IfMT04`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
1@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000W@3IfMT200000480fMWI
0P00003P0=WIf@8000004`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WI
f@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000W`3IfMT2000003h0fMWI0P00003T0=WIf@80
00004@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0
fMWI00@000000=WIf@3IfMT00000X@3IfMT2000003X0fMWI0P00003X0=WIf@8000003`3IfMT002D0
fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00002S
0=WIf@<00000=@3IfMT200000>`0fMWI00<000000=WIf@3IfMT0303IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000YP3I
fMT300000300fMWI0P00003m0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00002Y0=WIf@800000:`3IfMT300000?l0fMWI
000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000
003IfMT0fMWI00000:/0fMWI0P00000V0=WIf@<00000o`3IfMT30=WIf@009@3IfMT00`000000fMWI
0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000[@3IfMT30000
0200fMWI0`00003o0=WIf@H0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT000001`3IfMT010000000fMWI0=WIf@00002`0=WIf@H00000503IfMT600000?l0fMWI2@3IfMT0
02D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@040000003IfMT0
fMWI00000;H0fMWI5000003o0=WIf@l0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@00000
0=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfMT0fMWI000U0=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00@0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000003o0=WIfMT0fMWI000U
0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0000
003o0=WIfMT0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT00000203I
fMT200000?l0fMWIfP3IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000P0fMWI0P00
003o0=WIfMX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT00000203I
fMT200000?l0fMWIfP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@00
00080=WIf@800000o`3IfMWJ0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0
fMWI000000P0fMWI0P00003o0=WIfMX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@00000
0=WIf@3IfMT00000203IfMT200000?l0fMWIfP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@0000080=WIf@800000o`3IfMWJ0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@040000003I
fMT0fMWI000000P0fMWI0P00003o0=WIfMX0fMWI00080=WIf@@000001@3IfMT2000000D0fMWI1@00
00080=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WI
f@0000070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfMX0fMWI00070=WIf@800000
0P3IfMT2000000@0fMWI0P0000070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
8@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3I
fMT00000203IfMT200000?l0fMWIfP3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000203IfMT2
00000?l0fMWIfP3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00P0fMWI1@00000O0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WI
f@3IfMT000001`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI0?l0fMWIf@3I
fMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0
fMWI000000L0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI0=WIf@3o0=WIfMT0fMWI
00070=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WI
f@0000070=WIf@040000003IfMT0fMWI00000?l0fMWIi03IfMT000L0fMWI0P0000020=WIf@800000
3@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
103IfMT010000000fMWI0=WIf@0000070=WIf@040000003IfMT0fMWI00000?l0fMWIi03IfMT000P0
fMWI1000000=0=WIf@8000002P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00003o0=WIfN@0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@000007
0=WIf@040000003IfMT0fMWI00000?l0fMWIi03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000
o`3IfMWT0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@0
00000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00003o0=WIfN@0fMWI000U0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@04
0000003IfMT0fMWI00000?l0fMWIi03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWU0=WI
f@009@3IfMT300000240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WI
f@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWU0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT000001`3IfMT00`000000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT00000
0?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@04
0000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWU0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`00
0000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0000
00L0fMWI00<000000=WIf@000000o`3IfMWU0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WI
fND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3I
fMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WI
f@000000o`3IfMWU0=WIf@009@3IfMT300000240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000
fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3I
fMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WI
f@000000o`3IfMWU0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WIfND0fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WI
f@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWU0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT000001`3IfMT00`000000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT00000
0?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@04
0000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMWU0=WIf@009@3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`00
0000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0
fMWI0`00000Q0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`00
0000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT01000
0000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WI
f@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3I
fMWU0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000
1`3IfMT00`000000fMWI0000003o0=WIfND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1`3IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIi@3IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WI
fND0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@000008
0=WIf@800000o`3IfMWU0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@00000
0=WIf@3IfMT00000203IfMT200000?l0fMWIi@3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000
00070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfND0fMWI000U0=WIf@030000003I
fMT0fMWI0240fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003I
fMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000080=WIf@800000o`3IfMWU0=WIf@00
9@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0
fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000203IfMT200000?l0fMWIi@3IfMT0
02D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3I
fMT0000000L0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@3o0=WIfN<0fMWI
000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WI
f@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000
003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000090=WIf@030000003IfMT0fMWI
0?l0fMWIh`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3I
fMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D0
00000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3I
fMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3IfMT002D0fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000
00070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3I
fMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@04
0000003IfMT0fMWI00000?l0fMWIk`3IfMT000P0fMWI100000050=WIf@800000103IfMT6000000P0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WI
f@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3IfMT000L0fMWI0P000002
0=WIf@800000103IfMT2000000D0fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@030000003I
fMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00001`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI00070=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT02P3IfMT2000000X0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000
fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0
fMWI00000?l0fMWIk`3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<
0=WIf@030000003IfMT0fMWI00L0fMWI1@00000O0=WIf@030000003IfMT0fMWI00<0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3I
fMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WIf@00
1`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0
fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WIf@001`3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI00000006
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3I
fMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WIf@001`3IfMT200000080fMWI0P00
000:0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000L0
fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WIf@00203IfMT4000000`0fMWI100000090=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI
0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0
fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT01000
0000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WI
f@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WI
fNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000
fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WI
f@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U
0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3I
fMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@050000003I
fMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@<00000
8@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000070=WI
f@040000003IfMT0fMWI00000?l0fMWIk`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WI
f@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT01000
0000fMWI0=WIf@0000070=WIf@040000003IfMT0fMWI00000?l0fMWIk`3IfMT002D0fMWI00<00000
0=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT00000
1`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI
00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00@000000=WI
f@3IfMT00000o`3IfMW_0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@040000003IfMT0fMWI00000?l0fMWI
k`3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI
00@000000=WIf@3IfMT000001`3IfMT010000000fMWI0=WIf@00003o0=WIfNl0fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI
000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMW_0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q
0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000
003IfMT000000?l0fMWIl03IfMT002D0fMWI0`00000Q0=WIf@030000003IfMT0fMWI00<0fMWI00D0
00000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIl03IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT000001`3IfMT00`000000fMWI0000003o0=WIfO00fMWI000U0=WIf@030000003IfMT0fMWI0240
fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0fMWI00<00000
0=WIf@000000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIl03I
fMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0
fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00@0
00000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WIfO00fMWI000U0=WIf@030000003I
fMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI000000L0
fMWI00<000000=WIf@000000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT00000
0?l0fMWIl03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@05
0000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00@0fMWI00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WIfO00fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000L0fMWI
00<000000=WIf@000000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@00
00001`3IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIl03IfMT002D0
fMWI0`00000Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000070=WIf@030000003I
fMT000000?l0fMWIl03IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@03
0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI
00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0000003o0=WIfO00fMWI000U0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000L0fMWI00<00000
0=WIf@000000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI
00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3I
fMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT000000?l0fMWIl03IfMT002D0fMWI00<0
00000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT000001`3IfMT00`00
0000fMWI0000003o0=WIfO00fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI00000007
0=WIf@040000003IfMT0fMWI000000L0fMWI00<000000=WIf@000000o`3IfMW`0=WIf@009@3IfMT0
0`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000
00060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000080=WIf@80
0000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT01000
0000fMWI0=WIf@0000080=WIf@800000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WI
f@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000080=WIf@800000o`3IfMW`0=WIf@009@3I
fMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000080=WI
f@800000o`3IfMW`0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT0
10000000fMWI0=WIf@0000080=WIf@800000o`3IfMW`0=WIf@009@3IfMT300000240fMWI00<00000
0=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI
000000070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfO00fMWI000U0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o
0=WIfO00fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@00
0000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003I
fMT0fMWI000000P0fMWI0P00003o0=WIfO00fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0
fMWI000000070=WIf@040000003IfMT0fMWI000000P0fMWI0P00003o0=WIfO00fMWI000U0=WIf@03
0000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT00000
00H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000P0fMWI00<0
00000=WIf@3IfMT0o`3IfMW_0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@000000
1`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI0?l0fMWIk`3IfMT002D0fMWI
00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000203IfMT0
0`000000fMWI0=WIf@3o0=WIfNl0fMWI00080=WIf@@000001@3IfMT2000000@0fMWI1000000:0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI000000P0fMWI
00<000000=WIf@3IfMT0o`3IfMW_0=WIf@001`3IfMT200000080fMWI0P0000040=WIf@800000203I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3I
fMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@04
0000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT0o`3IfMW_0=WIf@001`3IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003I
fMT0fMWI0?l0fMWIk`3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<
0=WIf@030000003IfMT0fMWI00L0fMWI1@00000O0=WIf@030000003IfMT0fMWI00<0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI
0=WIf@0000080=WIf@030000003IfMT0fMWI0?l0fMWIk`3IfMT000L0fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0:0=WIf@8000002P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0fMWI0?l0fMWIk`3IfMT0
00L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI
0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000
o`3IfMWj0=WIf@001`3IfMT200000080fMWI0P00000>0=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWj0=WI
f@00203IfMT4000000`0fMWI0`00000:0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI00000007
0=WIf@040000003IfMT0fMWI00000?l0fMWInP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WI
f@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWj0=WIf@009@3IfMT00`000000fMWI
0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@05
0000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfOX0fMWI000U0=WI
f@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0
000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWI
nP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003I
fMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3I
fMT00000o`3IfMWj0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0
fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT0
10000000fMWI0=WIf@00003o0=WIfOX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<00000
0=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI
000000070=WIf@040000003IfMT0fMWI00000?l0fMWInP3IfMT002D0fMWI0`00000Q0=WIf@030000
003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WI
f@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfOX0fMWI000U0=WIf@030000003IfMT0fMWI
0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00D00000
0=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWInP3IfMT002D0fMWI00<0
00000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3IfMWj0=WI
f@009@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3I
fMT0fMWI000000060=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00
003o0=WIfOX0fMWI000U0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT0
1@000000fMWI0=WIf@3IfMT0000000H0fMWI00D000000=WIf@3IfMT0fMWI000000070=WIf@040000
003IfMT0fMWI00000?l0fMWInP3IfMT002D0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI
0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT01@000000fMWI0=WIf@3IfMT00000
00L0fMWI00@000000=WIf@3IfMT00000o`3IfMWj0=WIf@009@3IfMT00`000000fMWI0=WIf@0Q0=WI
f@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@050000003IfMT0
fMWI0=WIf@0000001`3IfMT010000000fMWI0=WIf@00003o0=WIfOX0fMWI000U0=WIf@030000003I
fMT0fMWI0240fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00D000000=WIf@3IfMT0fMWI000000070=WIf@040000003IfMT0fMWI00000?l0fMWInP3IfMT002D0
fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WI
f@0000001P3IfMT01@000000fMWI0=WIf@3IfMT0000000L0fMWI00@000000=WIf@3IfMT00000o`3I
fMWj0=WIf@00o`3IfMWo0=WIfFD0fMWI003o0=WIfOl0fMWII@3IfMT00?l0fMWIo`3IfMUU0=WIf@00
o`3IfMWo0=WIfFD0fMWI003o0=WIfOl0fMWII@3IfMT00?l0fMWIo`3IfMUU0=WIf@00o`3IfMWo0=WI
fFD0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 610.375}, {376.875, 0}} -> {-2.67167, -0.372586, \
0.0894367, 0.00239718}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Evaluate[xno[t] /. {x\_0 \[Rule] 5, 
            v\_0 \[Rule] 0.0, \[Omega]\_0 \[Rule] 4, \[Omega] \[Rule] 
              0.3, \[Gamma] \[Rule] 2.1, a\_0 \[Rule] 1}], {t, 0, 
        40}]\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0.309061 1.17263 [
[.2619 .29656 -6 -9 ]
[.2619 .29656 6 0 ]
[.5 .29656 -6 -9 ]
[.5 .29656 6 0 ]
[.7381 .29656 -6 -9 ]
[.7381 .29656 6 0 ]
[.97619 .29656 -6 -9 ]
[.97619 .29656 6 0 ]
[.01131 .07453 -24 -4.5 ]
[.01131 .07453 0 4.5 ]
[.01131 .1918 -24 -4.5 ]
[.01131 .1918 0 4.5 ]
[.01131 .42632 -18 -4.5 ]
[.01131 .42632 0 4.5 ]
[.01131 .54359 -18 -4.5 ]
[.01131 .54359 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .30906 m
.2619 .31531 L
s
[(10)] .2619 .29656 0 1 Mshowa
.5 .30906 m
.5 .31531 L
s
[(20)] .5 .29656 0 1 Mshowa
.7381 .30906 m
.7381 .31531 L
s
[(30)] .7381 .29656 0 1 Mshowa
.97619 .30906 m
.97619 .31531 L
s
[(40)] .97619 .29656 0 1 Mshowa
.125 Mabswid
.07143 .30906 m
.07143 .31281 L
s
.11905 .30906 m
.11905 .31281 L
s
.16667 .30906 m
.16667 .31281 L
s
.21429 .30906 m
.21429 .31281 L
s
.30952 .30906 m
.30952 .31281 L
s
.35714 .30906 m
.35714 .31281 L
s
.40476 .30906 m
.40476 .31281 L
s
.45238 .30906 m
.45238 .31281 L
s
.54762 .30906 m
.54762 .31281 L
s
.59524 .30906 m
.59524 .31281 L
s
.64286 .30906 m
.64286 .31281 L
s
.69048 .30906 m
.69048 .31281 L
s
.78571 .30906 m
.78571 .31281 L
s
.83333 .30906 m
.83333 .31281 L
s
.88095 .30906 m
.88095 .31281 L
s
.92857 .30906 m
.92857 .31281 L
s
.25 Mabswid
0 .30906 m
1 .30906 L
s
.02381 .07453 m
.03006 .07453 L
s
[(-0.2)] .01131 .07453 1 0 Mshowa
.02381 .1918 m
.03006 .1918 L
s
[(-0.1)] .01131 .1918 1 0 Mshowa
.02381 .42632 m
.03006 .42632 L
s
[(0.1)] .01131 .42632 1 0 Mshowa
.02381 .54359 m
.03006 .54359 L
s
[(0.2)] .01131 .54359 1 0 Mshowa
.125 Mabswid
.02381 .09799 m
.02756 .09799 L
s
.02381 .12144 m
.02756 .12144 L
s
.02381 .14489 m
.02756 .14489 L
s
.02381 .16835 m
.02756 .16835 L
s
.02381 .21525 m
.02756 .21525 L
s
.02381 .2387 m
.02756 .2387 L
s
.02381 .26216 m
.02756 .26216 L
s
.02381 .28561 m
.02756 .28561 L
s
.02381 .33251 m
.02756 .33251 L
s
.02381 .35597 m
.02756 .35597 L
s
.02381 .37942 m
.02756 .37942 L
s
.02381 .40287 m
.02756 .40287 L
s
.02381 .44978 m
.02756 .44978 L
s
.02381 .47323 m
.02756 .47323 L
s
.02381 .49668 m
.02756 .49668 L
s
.02381 .52013 m
.02756 .52013 L
s
.02381 .05108 m
.02756 .05108 L
s
.02381 .02763 m
.02756 .02763 L
s
.02381 .00418 m
.02756 .00418 L
s
.02381 .56704 m
.02756 .56704 L
s
.02381 .59049 m
.02756 .59049 L
s
.02381 .61394 m
.02756 .61394 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03479 .61803 m
.03543 .21084 L
s
.03543 .21084 m
.03583 0 L
s
.0531 0 m
.0551 .51937 L
s
.0551 .51937 m
.05558 .61803 L
s
.07176 .61803 m
.07312 .45669 L
.07573 .19089 L
.07706 .08756 L
.07852 .00179 L
s
.07852 .00179 m
.07856 0 L
s
.08551 0 m
.0891 .14988 L
.09408 .39295 L
.09533 .44078 L
.09668 .48253 L
.09745 .50159 L
.09816 .5158 L
.09887 .52697 L
.09954 .53472 L
.10079 .54195 L
.10195 .54084 L
.10322 .53186 L
.10394 .52373 L
.10458 .5147 L
.10719 .46582 L
.11 .40186 L
.11244 .34827 L
.11382 .32165 L
.1151 .3004 L
.11642 .28275 L
.11762 .27058 L
.11891 .26174 L
.11961 .25868 L
.12028 .25691 L
.12147 .25632 L
.12256 .25841 L
.12376 .26322 L
.12504 .27065 L
.12929 .30489 L
.13153 .32325 L
.13388 .33915 L
.13513 .34555 L
.1358 .34826 L
.1365 .35061 L
.13775 .35339 L
.13891 .35444 L
.14018 .35396 L
.14138 .35208 L
.14246 .34936 L
.14363 .34547 L
.14859 .32267 L
.15133 .30964 L
.15392 .29929 L
.15509 .29555 L
.15633 .29226 L
.15698 .29085 L
.15769 .28951 L
.15895 .28772 L
.16009 .28669 L
.16132 .28614 L
Mistroke
.16248 .28609 L
.16354 .28636 L
.16475 .28697 L
.16587 .28773 L
.16843 .28976 L
.1697 .29073 L
.17091 .29151 L
.17158 .29186 L
.17231 .29216 L
.17357 .29248 L
.17426 .29253 L
.1749 .2925 L
.1756 .29236 L
.17636 .29211 L
.17715 .29173 L
.1779 .29125 L
.17931 .29008 L
.18184 .2872 L
.1846 .28326 L
.18947 .27571 L
.19203 .27209 L
.19474 .26883 L
.19711 .26653 L
.19971 .26455 L
.20208 .26316 L
.20428 .26212 L
.2096 .25993 L
.21529 .25715 L
.22526 .25058 L
.2302 .24735 L
.23544 .24449 L
.2412 .24212 L
.24652 .24044 L
.25609 .23799 L
.26123 .23688 L
.26403 .23637 L
.26664 .23598 L
.26898 .2357 L
.27017 .23559 L
.27147 .23549 L
.27221 .23544 L
.27289 .23541 L
.27353 .23538 L
.27423 .23536 L
.27545 .23533 L
.27675 .23533 L
.27795 .23535 L
.27905 .23538 L
.28032 .23544 L
.28153 .23552 L
Mistroke
.28367 .2357 L
.286 .23596 L
.29125 .23675 L
.29683 .2379 L
.30687 .24081 L
.31719 .24497 L
.32833 .2507 L
.34852 .26387 L
.3896 .29856 L
.42915 .33469 L
.44907 .35103 L
.4672 .36364 L
.48676 .37406 L
.49192 .37617 L
.49752 .37814 L
.50277 .37968 L
.5077 .38084 L
.51224 .38166 L
.51479 .38202 L
.51713 .38229 L
.51968 .3825 L
.52112 .38259 L
.52181 .38262 L
.52246 .38265 L
.52374 .38269 L
.52491 .3827 L
.52616 .38271 L
.52687 .3827 L
.52752 .38269 L
.52874 .38265 L
.53004 .38259 L
.53127 .38252 L
.5324 .38244 L
.53514 .38218 L
.53775 .38185 L
.54292 .38096 L
.54855 .37965 L
.55794 .37668 L
.56831 .3723 L
.58932 .36023 L
.62951 .32812 L
.66819 .29259 L
.68782 .27551 L
.70931 .2592 L
.71923 .25283 L
.72983 .247 L
.73976 .24253 L
.74892 .23934 L
.7539 .23799 L
.75916 .23687 L
Mistroke
.76171 .23644 L
.76445 .23606 L
.76602 .23588 L
.76745 .23574 L
.76881 .23563 L
.77026 .23554 L
.77095 .23551 L
.77161 .23548 L
.77283 .23544 L
.77397 .23542 L
.7752 .23541 L
.77586 .23542 L
.77657 .23543 L
.77732 .23545 L
.77801 .23547 L
.77926 .23552 L
.7806 .2356 L
.78323 .23582 L
.78573 .23609 L
.79041 .23681 L
.79501 .23775 L
.80008 .23908 L
.81035 .24262 L
.81986 .24689 L
.82878 .25172 L
.86751 .28007 L
.90869 .31746 L
.94835 .3515 L
.97619 .3696 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{505.938, 312.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009h0001QR000`400?l00000o`00003oo`3IfMWo
0=WIfGX0fMWI003o0=WIfOl0fMWINP3IfMT00?l0fMWIo`3IfMUj0=WIf@00o`3IfMWo0=WIfGX0fMWI
003o0=WIfOl0fMWINP3IfMT00?l0fMWIo`3IfMUj0=WIf@00o`3IfMWo0=WIfGX0fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB`0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB`0fMWI000U0=WIf@<00000103I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@3o0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o
0=WIfOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WI
fOl0fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0
fMWI;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI
;03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI;03I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI;03IfMT002D0fMWI
0`0000040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WI
f@020=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0?l0fMWIo`3IfMT/0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0
fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0fMWI
o`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[
0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WI
f@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@00
9@3IfMT3000000@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
o`3IfMWo0=WIfB/0fMWI00080=WIf@@000001@3IfMT2000000@0fMWI1P0000080=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI00070=WIf@8000000P3IfMT2
000000@0fMWI0P0000050=WIf@050000003IfMT0fMWI0=WIf@000000203IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@001`3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI00X0fMWI0P00000:0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI00070=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0303IfMT00`000000fMWI0=WIf@070=WIf@D000000P3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3o0=WI
fOl0fMWI:`3IfMT000040=WIf@0000000000000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@3o0=WIfOl0fMWI:`3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@3o0=WIfOl0fMWI:`3IfMT000L0fMWI0P0000020=WIf@8000002P3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@3o0=WIfOl0fMWI:`3IfMT000P0fMWI1000000<0=WIf@@000002@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0
fMWIo`3IfMT[0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWI
o`3IfMT[0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0o`3IfMWo0=WIfB/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@<00000103IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI
:P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT002D0fMWI0`0000040=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWI
o`3IfMTZ0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTZ0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ
0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WI
f@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMTZ0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3I
fMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
o`3IfMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3I
fMWo0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo
0=WIfBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WI
fBX0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0
fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBX0fMWI00080=WIf@@00000
1@3IfMT2000000D0fMWI1@0000080=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
o`3IfMWo0=WIfBX0fMWI00070=WIf@8000000P3IfMT2000000@0fMWI0P0000070=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3I
fMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:P3IfMT0
00L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00P0fMWI1@0000020=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@0000@0fMWI00000000
000000000`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WI
f@001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@00
1`3IfMT200000080fMWI0P00000=0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI:@3IfMT000P0fMWI1000000=0=WIf@8000002P3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@030000003I
fMT0fMWI0?l0fMWIo`3IfMTY0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo
0=WIfBT0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WI
fBT0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0
fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfBT0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0IP3IfMT@00000?l0fMWI803IfMT@00000880fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0H03IfMT600000100fMWI1P00003o0=WIfA@0fMWI
1P00000@0=WIf@H00000O03IfMT002D0fMWI0`0000040=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI05h0fMWI0P00
000L0=WIf@<00000o`3IfMT>0=WIf@<00000703IfMT3000007T0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0
fMWI00H0fMWI00<000000=WIf@3IfMT0F`3IfMT300000240fMWI0`00003o0=WIf@T0fMWI0P00000R
0=WIf@@00000M@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@1G0=WI
f@@000009`3IfMT200000?l0fMWI1@3IfMT2000002P0fMWI0P00001c0=WIf@009@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@060=WIf@030000003IfMT0fMWI05D0fMWI0P00000]0=WIf@800000o`3IfMT10=WIf@80
0000;03IfMT200000740fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
D`3IfMT200000340fMWI0P00003l0=WIf@800000<03IfMT2000006l0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0DP3IfMT00`000000fMWI0=WIf@0c0=WIf@800000m`3I
fMT3000003@0fMWI00<000000=WIf@3IfMT0K03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@1@0=WIf@800000>03IfMT200000?<0fMWI0P00000h0=WIf@800000K03IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
00/0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@1?0=WIf@030000003IfMT0fMWI
03X0fMWI0P00003_0=WIf@800000?03IfMT2000006X0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0C@3IfMT2000003l0fMWI0P00003[0=WIf@800000@03IfMT2000006P0
fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0C03IfMT00`000000fMWI
0=WIf@110=WIf@800000i`3IfMT2000004@0fMWI0P00001V0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI04X0fMWI0P0000160=WIf@030000003IfMT0fMWI0><0fMWI00<0
00000=WIf@3IfMT0AP3IfMT00`000000fMWI0=WIf@1S0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI00l0fMWI0P00000h0=WIf@030000003IfMT0fMWI04L0fMWI0P00003Q
0=WIf@800000BP3IfMT00`000000fMWI0=WIf@1R0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00h0fMWI00<000000=WIf@000000=P3IfMT2000004`0fMWI00<000000=WI
f@3IfMT0g@3IfMT00`000000fMWI0=WIf@1;0=WIf@800000HP3IfMT002D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0000003<0fMWI0`00001?0=WIf@80
0000g03IfMT00`000000fMWI0=WIf@1>0=WIf@030000003IfMT0fMWI05l0fMWI000U0=WIf@<00000
103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@0>0=WIf@040000003IfMT0fMWI00000300fMWI0P00001D0=WIf@80
0000f03IfMT200000580fMWI00<000000=WIf@3IfMT0GP3IfMT002D0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@0>0=WIf@040000003IfMT0fMWI000002l0fMWI00<000000=WIf@3I
fMT0EP3IfMT00`000000fMWI0=WIf@3D0=WIf@030000003IfMT0fMWI05<0fMWI0P00001N0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00h0fMWI00@000000=WIf@3IfMT0
0000;@3IfMT2000005X0fMWI00<000000=WIf@3IfMT0dP3IfMT00`000000fMWI0=WIf@1F0=WIf@03
0000003IfMT0fMWI05/0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
3@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0
F`3IfMT00`000000fMWI0=WIf@3?0=WIf@800000FP3IfMT00`000000fMWI0=WIf@1J0=WIf@009@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT00P3I
fMT00`000000fMWI0=WIf@0W0=WIf@800000G`3IfMT200000<h0fMWI00<000000=WIf@3IfMT0F`3I
fMT2000005X0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0H@3IfMT0
0`000000fMWI0=WIf@3:0=WIf@030000003IfMT0fMWI05h0fMWI00<000000=WIf@3IfMT0E`3IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@1S0=WIf@030000003IfMT0fMWI
0<L0fMWI0P00001R0=WIf@030000003IfMT0fMWI05H0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI02@0
fMWI00<000000=WIf@3IfMT0I@3IfMT00`000000fMWI0=WIf@350=WIf@030000003IfMT0fMWI06<0
fMWI0P00001F0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI06H0fMWI
00<000000=WIf@3IfMT0``3IfMT00`000000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI05<0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT0J03IfMT200000<80fMWI00<0
00000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@1B0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0S
0=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3IfMT0_P3IfMT00`000000fMWI0=WIf@1Z
0=WIf@800000DP3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@0U0=WI
f@D000000`3IfMT4000003/0fMWI00<000000=WIf@3IfMT0AP3IfMT6000000<0fMWI1000001Y0=WI
f@030000003IfMT0fMWI01P0fMWI100000050=WIf@@00000B03IfMT00`000000fMWI0=WIf@0j0=WI
f@<00000103IfMT4000000X0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3I
fMT09`3IfMT00`000000fMWI0=WIf@020=WIf@8000000P3IfMT2000003/0fMWI00<000000=WIf@3I
fMT0AP3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI0P0000020=WIf@800000I`3IfMT00`00
0000fMWI0=WIf@0M0=WIf@040000003IfMT0fMWI0=WIf@8000000P3IfMT2000004P0fMWI00<00000
0=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@020=WIf@8000000P3IfMT2000000T0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@160=WI
f@800000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI06@0fMWI00<000000=WI
f@3IfMT07P3IfMT01@000000fMWI0=WIf@3IfMT0000000@0fMWI00<000000=WIf@3IfMT0A`3IfMT0
0`000000fMWI0=WIf@0f0=WIf@D000000`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI00L0fMWI000U0=WIf@<00000103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0k0=WIf@800000B03IfMT01@00
0000fMWI0=WIf@3IfMT0000000@0fMWI00<000000=WIf@3IfMT0HP3IfMT200000240fMWI00D00000
0=WIf@3IfMT0fMWI000000040=WIf@030000003IfMT0fMWI04P0fMWI00<000000=WIf@3IfMT0=@3I
fMT010000000fMWI0=WIf@0000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
1`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT04@3IfMT4000000T0fMWI00<000000=WIf@3IfMT0:P3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0?@3I
fMT00`000000fMWI0=WIf@160=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0
H@3IfMT00`000000fMWI0=WIf@0O0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI04T0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI000000040=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01`3IfMT002D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0403I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0:`3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0?P3I
fMT00`000000fMWI0=WIf@150=WIf@040000003IfMT0fMWI000000@0fMWI00<000000=WIf@3IfMT0
H03IfMT00`000000fMWI0=WIf@0R0=WIf@050000003IfMT0fMWI0=WIf@000000103IfMT00`000000
fMWI0=WIf@1:0=WIf@030000003IfMT0fMWI03@0fMWI00<000000=WIf@000000103IfMT00`000000
fMWI0=WIf@020=WIf@030000003IfMT0fMWI00L0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0100fMWI
00<000000=WIf@3IfMT00`3IfMT2000000D0fMWI00<000000=WIf@3IfMT0:`3IfMT00`000000fMWI
0=WIf@020=WIf@8000000P3IfMT200000440fMWI00<000000=WIf@3IfMT0?`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI008000000P3IfMT200000640fMWI00<000000=WIf@3IfMT0
8`3IfMT010000000fMWI0=WIf@3IfMT200000080fMWI0P00001=0=WIf@800000=@3IfMT2000000@0
fMWI0P0000020=WIf@8000002@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0000000800000;@3IfMT2000000D0fMWI100000130=WIf@030000
003IfMT0fMWI03l0fMWI100000040=WIf@@00000H@3IfMT00`000000fMWI0=WIf@0Q0=WIf@<00000
1@3IfMT400000500fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000fMWI0=WIf@030=WIf@@00000
2P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@080=WIf@800000OP3I
fMT200000:/0fMWI00<000000=WIf@3IfMT0O`3IfMT00`000000fMWI0=WIf@160=WIf@009@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI08X0fMWI00<000000=WIf@3IfMT0Y`3IfMT0
0`000000fMWI0=WIf@210=WIf@030000003IfMT0fMWI04D0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT0R`3IfMT00`000000fMWI0=WIf@2U0=WIf@030000003IfMT0fMWI
08<0fMWI00<000000=WIf@3IfMT0A03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0303IfMT00`000000
fMWI0=WIf@2=0=WIf@030000003IfMT0fMWI0:<0fMWI00<000000=WIf@3IfMT0Q@3IfMT00`000000
fMWI0=WIf@130=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI08h0fMWI
00<000000=WIf@3IfMT0X@3IfMT00`000000fMWI0=WIf@270=WIf@030000003IfMT0fMWI0480fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0S`3IfMT00`000000fMWI0=WI
f@2N0=WIf@800000R`3IfMT00`000000fMWI0=WIf@110=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0<
0=WIf@030000003IfMT0fMWI0900fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@2<
0=WIf@030000003IfMT0fMWI0400fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WI
f@3IfMT0TP3IfMT00`000000fMWI0=WIf@2J0=WIf@030000003IfMT0fMWI08h0fMWI00<000000=WI
f@3IfMT0?`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@2C0=WIf@03
0000003IfMT0fMWI09P0fMWI00<000000=WIf@3IfMT0T03IfMT00`000000fMWI0=WIf@0n0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI09@0fMWI0P00002G0=WIf@030000
003IfMT0fMWI0980fMWI0P00000n0=WIf@005`3IfMWo00000?l00000H`00000002D0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@0000002P3IfMT00`000000fMWI0=WIf@0:0=WIf@040000003IfMT0fMWI000000H0fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI01X0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI00@0
00000=WIf@3IfMT000006@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00d0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0000000X0fMWI00<000000=WIf@3IfMT02P3IfMT010000000fMWI0=WI
f@0000060=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI
0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI0P00000K0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@0000006P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00d0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@070=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0@@3IfMT00`000000fMWI0=WI
f@1F0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0E@3IfMT00`000000fMWI0=WI
f@0f0=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WI
f@0=0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI09/0fMWI00<00000
0=WIf@3IfMT0R`3IfMT00`000000fMWI0=WIf@2M0=WIf@030000003IfMT0fMWI03L0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@290=WI
f@030000003IfMT0fMWI09l0fMWI00<000000=WIf@3IfMT0=P3IfMT002D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT01`3IfMT00`000000fMWI0=WIf@2N0=WIf@030000003IfMT0fMWI08H0fMWI0P00002S0=WIf@03
0000003IfMT0fMWI03D0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
W`3IfMT00`000000fMWI0=WIf@240=WIf@030000003IfMT0fMWI0:@0fMWI00<000000=WIf@3IfMT0
=03IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@2P0=WIf@030000003I
fMT0fMWI0880fMWI00<000000=WIf@3IfMT0YP3IfMT2000003@0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0X@3IfMT00`000000fMWI0=WIf@200=WIf@030000003IfMT0
fMWI0:T0fMWI00<000000=WIf@3IfMT0<@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT01`3IfMT00`00
0000fMWI0=WIf@2R0=WIf@800000O`3IfMT00`000000fMWI0=WIf@2[0=WIf@030000003IfMT0fMWI
0300fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0Y@3IfMT00`000000
fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI0:d0fMWI00<000000=WIf@3IfMT0;`3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2V0=WIf@030000003IfMT0fMWI07T0fMWI
00<000000=WIf@3IfMT0[`3IfMT00`000000fMWI0=WIf@0^0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI0:L0fMWI00<000000=WIf@3IfMT0MP3IfMT200000;<0fMWI0P00
000^0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0Z03IfMT00`000000fMWI0=WIf@1d
0=WIf@030000003IfMT0fMWI0;D0fMWI00<000000=WIf@3IfMT0:`3IfMT002D0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@2Z0=WIf@030000003IfMT0fMWI0780fMWI00<000000=WI
f@3IfMT0]`3IfMT00`000000fMWI0=WIf@0Z0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0:/0fMWI00<000000=WIf@3IfMT0L03IfMT00`000000fMWI0=WIf@2i0=WIf@03
0000003IfMT0fMWI02T0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
[03IfMT00`000000fMWI0=WIf@1]0=WIf@800000_@3IfMT00`000000fMWI0=WIf@0X0=WIf@009@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0:d0fMWI0P00001/0=WIf@030000003I
fMT0fMWI0;h0fMWI0P00000X0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0:l0fMWI00<000000=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@310=WIf@030000003IfMT0
fMWI02D0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0/@3IfMT00`00
0000fMWI0=WIf@1V0=WIf@030000003IfMT0fMWI0<<0fMWI00<000000=WIf@3IfMT0903IfMT002D0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00/0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@2b0=WIf@030000003IfMT0fMWI06<0
fMWI0P0000370=WIf@030000003IfMT0fMWI02<0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT0/`3IfMT00`000000fMWI0=WIf@1Q0=WIf@030000003IfMT0fMWI0<P0fMWI
00<000000=WIf@3IfMT08P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00/0fMWI00D000000=WIf@3IfMT0fMWI0000002g0=WIf@800000
H03IfMT00`000000fMWI0=WIf@3:0=WIf@8000008P3IfMT002D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00`0fMWI00@000000=WIf@3IfMT00000
^@3IfMT00`000000fMWI0=WIf@1L0=WIf@030000003IfMT0fMWI0<d0fMWI00<000000=WIf@3IfMT0
7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00`0fMWI00@000000=WIf@3IfMT00000^P3IfMT00`000000fMWI0=WIf@1I0=WIf@800000
d@3IfMT00`000000fMWI0=WIf@0N0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0303IfMT010000000fMWI0=WIf@00002k0=WIf@800000
F03IfMT00`000000fMWI0=WIf@3B0=WIf@8000007P3IfMT002D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI0`00002n0=WIf@030000003I
fMT0fMWI05@0fMWI00<000000=WIf@3IfMT0e@3IfMT00`000000fMWI0=WIf@0K0=WIf@009@3IfMT3
000000@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3>0=WIf@030000003IfMT0
fMWI0580fMWI00<000000=WIf@3IfMT0e`3IfMT2000001/0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3?0=WIf@800000D03IfMT20000
0=`0fMWI00<000000=WIf@3IfMT0603IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=40fMWI00<000000=WIf@3IfMT0C03IfMT00`000000
fMWI0=WIf@3M0=WIf@800000603IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI0=80fMWI00<000000=WIf@3IfMT0BP3IfMT00`000000fMWI
0=WIf@3P0=WIf@8000005P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI0=<0fMWI0P0000180=WIf@800000i@3IfMT00`000000fMWI0=WI
f@0C0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT0e@3IfMT00`000000fMWI0=WIf@130=WIf@800000j03IfMT2000001<0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3F0=WI
f@800000@@3IfMT200000>`0fMWI00<000000=WIf@3IfMT0403IfMT002D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0=P0fMWI0P00000m0=WIf@80
0000k`3IfMT200000100fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@3J0=WIf@800000>@3IfMT200000?<0fMWI00<000000=WIf@3IfMT0
3@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI0=`0fMWI0P00000e0=WIf@800000o`3IfMT60=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0gP3IfMT200000380fMWI00<00000
0=WIf@3IfMT0o`3IfMT60=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT0h03IfMT3000002d0fMWI0P00003o0=WIf@T0fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3T0=WIf@80
0000:@3IfMT200000?l0fMWI2`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI0>H0fMWI0P00000T0=WIf@<00000o`3IfMT=0=WIf@009@3I
fMT3000000@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3X0=WIf@8000007`3I
fMT300000?l0fMWI403IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI0>X0fMWI1P00000C0=WIf@H00000o`3IfMTC0=WIf@009@3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0l03IfMTC0000
0?l0fMWI6@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI0?l0fMWIo`3IfMTM0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0
fMWI0?l0fMWIo`3IfMTM0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWI
o`3IfMTM0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<0
00000=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT002D0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTM0=WI
f@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT002D0fMWI0`0000040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTM0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0
fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT002D0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTM0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfAd0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7@3IfMT002D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTM0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
o`3IfMWo0=WIfAh0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT000P0fMWI100000050=WIf@8000001@3IfMT5
000000P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0?l0fMWIo`3IfMTN0=WIf@001`3IfMT200000080fMWI0P0000040=WIf@8000001`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTN0=WIf@001`3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0203IfMT500000080fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT000L0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTN0=WIf@001`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfAh0fMWI00070=WIf@8000000P3IfMT2000000d0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT0o`3IfMWo0=WIfAh0fMWI00080=WIf@@000003@3IfMT2000000X0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT02`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTN0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
o`3IfMWo0=WIfAh0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT0
0`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTN0=WIf@009@3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WI
fAh0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTN0=WIf@009@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAh0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o
0=WIfOl0fMWI7P3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMTN0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7P3IfMT002D0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
2`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTO0=WIf@009@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3I
fMWo0=WIfAl0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@3o0=WIfOl0fMWI7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTO0=WIf@009@3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAl0
fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI
0=WIf@3o0=WIfOl0fMWI7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTO0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAl0fMWI000U0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3o0=WI
fOl0fMWI7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI0?l0fMWIo`3IfMTO0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000
003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAl0fMWI000U0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI7`3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0?l0fMWIo`3IfMTO0=WIf@009@3IfMT3000000@0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@3o0=WIfOl0fMWI7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTO0=WIf@009@3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfAl0fMWI
000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@3o0=WIfOl0fMWI7`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB00fMWI000U0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@03
0000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0
fMWI803IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000
003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB00fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI803IfMT0
02D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB00fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI
00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI803IfMT002D0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<0
00000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0o`3IfMWo0=WIfB00fMWI000U0=WIf@<00000103IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI0?l0fMWIo`3IfMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfB00fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI
803IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI0?l0fMWIo`3IfMTP0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@050000003IfMT0
fMWI0=WIf@000000o`3IfMWo0=WIfB<0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00`0fMWI00D00000
0=WIf@3IfMT0fMWI0000003o0=WIfOl0fMWI8`3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT0
1@000000fMWI0=WIf@3IfMT000000?l0fMWIo`3IfMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<
0=WIf@050000003IfMT0fMWI0=WIf@000000o`3IfMWo0=WIfB<0fMWI000U0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0
fMWI00`0fMWI00D000000=WIf@3IfMT0fMWI0000003o0=WIfOl0fMWI8`3IfMT002D0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT0303IfMT01@000000fMWI0=WIf@3IfMT000000?l0fMWIo`3IfMTS0=WIf@009@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0<0=WIf@050000003IfMT0fMWI0=WIf@000000o`3IfMWo0=WIfB<0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI00`0fMWI00D000000=WIf@3IfMT0fMWI0000003o0=WIfOl0fMWI8`3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT01@000000fMWI0=WIf@3IfMT000000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@050000003IfMT0fMWI0=WIf@000000o`3I
fMWo0=WIfB<0fMWI000U0=WIf@<00000103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0303IfMT01@000000fMWI0=WIf@3IfMT000000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@040000003IfMT0fMWI00000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@040000003IfMT0fMWI00000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@040000003IfMT0fMWI00000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@040000003IfMT0fMWI00000?l0fMWIo`3I
fMTS0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT
0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT0=WI
f@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
203IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT0=WIf@009@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203I
fMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT0=WIf@009@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@0=0=WIf@030000003IfMT000000?l0fMWIo`3IfMTT0=WIf@00203IfMT40000
00D0fMWI0P0000040=WIf@H00000203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0?0=WIf@800000o`3IfMWo0=WI
fB@0fMWI00070=WIf@8000000P3IfMT2000000@0fMWI0P0000050=WIf@050000003IfMT0fMWI0=WI
f@000000203IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WI
f@3IfMT01`3IfMT00`000000fMWI0=WIf@0?0=WIf@800000o`3IfMWo0=WIfB@0fMWI00070=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT02P3IfMT2000000X0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT03`3IfMT200000?l0fMWIo`3IfMTT0=WIf@001`3IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT01`3IfMT500000080fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@001`3I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT000L0fMWI00<000000=WIf@3IfMT00P3IfMT0
0`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0103IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo
0=WIfCD0fMWI00070=WIf@8000000P3IfMT2000000X0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@00203IfMT4000000`0
fMWI100000090=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000
fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI
0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WI
fOl0fMWI=@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI
0`0000040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U
0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WI
fOl0fMWI=@3IfMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@<00000103IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003I
fMT0fMWI00T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3I
fMT002D0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@00
9@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o`3I
fMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3IfMTe0=WIf@009@3IfMT30000
00@0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?l0fMWIo`3IfMTe0=WIf@009@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00T0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIfOl0fMWI=@3IfMT002D0fMWI
00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI
00<000000=WIf@3IfMT0o`3IfMWo0=WIfCD0fMWI000U0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0?l0fMWIo`3I
fMTe0=WIf@00o`3IfMWo0=WIfGX0fMWI003o0=WIfOl0fMWINP3IfMT00?l0fMWIo`3IfMUj0=WIf@00
o`3IfMWo0=WIfGX0fMWI003o0=WIfOl0fMWINP3IfMT00?l0fMWIo`3IfMUj0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 631.375}, {389.812, 0}} -> {-2.59671, -0.273304, \
0.0863135, 0.00175254}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
The solution when the external frequency equals natural frequency\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solres\  = \ 
      DSolve[\(x''\)[
              t] + \[Gamma]\ \(x'\)[t] + \ \[Omega]\^2\ x[t]\  \[Equal] \ 
          a\_0\ Cos[\[Omega]\ t], x, t]; 
    xres[t_]\  = \ x[t] /. solres[\([1]\)] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ t\ \((\[Gamma] + \@\(\[Gamma]\^2 - 4\ \
\[Omega]\^2\))\)\)\ \((C[
              1] + \[ExponentialE]\^\(t\ \@\(\[Gamma]\^2 - 4\ \[Omega]\^2\)\)\
\ C[2])\) + \(a\_0\ Sin[t\ \[Omega]]\)\/\(\[Gamma]\ \[Omega]\)\)], "Output"]
}, Open  ]],

Cell["When no damping. solution grows linearly with time. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(solres0\  = \ 
      DSolve[\(x''\)[t] + \ \[Omega]\^2\ x[t]\  \[Equal] \ 
          a\_0\ Cos[\[Omega]\ t], x, t]; 
    xres0[t_]\  = \ x[t] /. solres0[\([1]\)] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(\(\((a\_0 + 4\ \[Omega]\^2\ C[1])\)\ Cos[t\ \[Omega]] + 2\ \[Omega]\ \
\((a\_0\ t + 2\ \[Omega]\ C[2])\)\ Sin[t\ \[Omega]]\)\/\(4\ \[Omega]\^2\)\)], \
"Output"]
}, Open  ]],

Cell["\<\
Solution in terms of initial conditions: (why trivial? Check \
later...)\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(solcres\  = \ 
        Solve[{xres[t]\  \[Equal] \ x\_0, \(xres'\)[t] \[Equal] \ v\_0}, {C[
                1], C[2]}] // Simplify;\)\), "\[IndentingNewLine]", 
    \(xr[t_]\  = \ xres[t]\  /. solcres[\([1]\)] // Simplify\)}], "Input"],

Cell[BoxData[
    \(x\_0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(solcres0\  = 
        Solve[{xres0[t]\  \[Equal] \ x\_0, \(xres0'\)[t] \[Equal] \ v\_0}, {C[
                1], C[2]}] // Simplify;\)\), "\[IndentingNewLine]", 
    \(xr0[t_]\  = \ xres0[t]\  /. solcres0[\([1]\)]\  // Simplify\)}], "Input"],

Cell[BoxData[
    \(x\_0\)], "Output"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{830, 880},
WindowMargins->{{115, Automatic}, {Automatic, 48}},
Visible->True,
ShowSelection->True,
InputAliases->{"intt"->RowBox[ {"\[Integral]", 
        RowBox[ {"\[SelectionPlaceholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "dintt"->RowBox[ {
        SubsuperscriptBox[ 
        "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
        RowBox[ {"\[Placeholder]", 
          RowBox[ {"\[DifferentialD]", "\[Placeholder]"}]}]}], 
    "sumt"->RowBox[ {
        UnderoverscriptBox[ "\[Sum]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "prodt"->RowBox[ {
        UnderoverscriptBox[ "\[Product]", 
          RowBox[ {"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
          "\[Placeholder]"], "\[Placeholder]"}], "dt"->RowBox[ {
        SubscriptBox[ "\[PartialD]", "\[Placeholder]"], " ", 
        "\[SelectionPlaceholder]"}], "notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {"\"\[Placeholder]\"", "\[Rule]", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Title"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style. Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.4, 0, 0.239994]},
    ScriptMinSize->9,
    Background->RGBColor[1, 0.960006, 0.900008]],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
    ScriptMinSize->9,
    Background->RGBColor[1, 0.960006, 0.900008]],
  
  Cell[StyleData[All, "SlideShow"],
    PageWidth->WindowWidth,
    ScrollingOptions->{"PagewiseDisplay"->True,
    "VerticalScrollRange"->Fit},
    ShowCellBracket->False,
    CellBracketOptions->{"Color"->RGBColor[0.744411, 0.47155, 0.371542]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ShowCellLabel->False,
    ImageSize->{200, 200},
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {0, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CellFrameColor->GrayLevel[0],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{0.95, 13},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[0.4, 0, 0.239994]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{28, 10}, {2, 30}},
    CellFrameMargins->{{0, 0}, {0, 12}},
    FontSize->54],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{18, 30}, {0, 0}},
    CellFrameMargins->4,
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{20, 30}, {2, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{30, 30}, {4, 16}},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section 1"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section 1", "Presentation"],
    CellFrame->{{0, 0}, {0, 5}},
    CellMargins->{{28, 10}, {16, 44}},
    CellFrameMargins->{{0, 0}, {0, 6}},
    FontSize->27],
  
  Cell[StyleData["Section 1", "Printout"],
    CellMargins->{{18, 30}, {4, 30}},
    CellFrameMargins->4,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.25}},
    CellMargins->{{18, 10}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->4,
    CellFrameColor->RGBColor[0.4, 0, 0.239994],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, 10}, {14, 42}},
    CellFrameMargins->{{0, 0}, {0, 6}},
    FontSize->27],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{38, 30}, {2, 20}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{58, 30}, {6, 34}},
    FontSize->21],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{18, 30}, {0, 10}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{55, 30}, {4, 10}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{80, 30}, {8, 12}},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{18, 30}, {0, 12}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{55, 10}, {6, 6}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontFamily->"Times",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{80, 10}, {10, 8}},
    FontSize->18],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Commentary"],
    CellMargins->{{55, 10}, {2, 6}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 0.4]],
  
  Cell[StyleData["Commentary", "Presentation"],
    CellMargins->{{80, 10}, {2, 10}},
    FontSize->15],
  
  Cell[StyleData["Commentary", "Printout"],
    CellMargins->{{18, 30}, {3, 0}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Inert"],
    StyleMenuListing->None,
    Background->RGBColor[0.870588, 0.905882, 0.972549]],
  
  Cell[StyleData["Inert", "Printout"],
    StyleMenuListing->None,
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->{{1, 1}, {0, 1}},
    CellMargins->{{55, 10}, {0, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["Input", "Presentation"],
    CellFrame->{{2, 2}, {0, 2}},
    CellMargins->{{80, 18}, {0, 2}},
    CellFrameMargins->{{10, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{55, 10}, {0, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->GrayLevel[0.850004]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInput"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInput", "Presentation"],
    CellMargins->{{10, 18}, {6, 4}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->{{1, 1}, {1, 0}},
    CellMargins->{{55, 10}, {15, 0}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    FontSize->12,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Output", "Presentation"],
    CellFrame->{{2, 2}, {2, 0}},
    CellMargins->{{80, 18}, {16, 0}},
    CellFrameMargins->{{12, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{55, Inherited}, {10, 0}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InputOnly"],
    CellFrame->1,
    CellMargins->{{55, 10}, {15, 0}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelPositioning->Automatic,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    FontSize->12,
    FontWeight->"Bold",
    Background->GrayLevel[0.966674]],
  
  Cell[StyleData["InputOnly", "Presentation"],
    CellFrame->2,
    CellMargins->{{80, 18}, {24, 4}},
    CellFrameMargins->{{10, 10}, {12, 12}},
    FontSize->18],
  
  Cell[StyleData["InputOnly", "Printout"],
    CellMargins->{{55, Inherited}, {10, 10}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellFrame->{{1, 1}, {0, 0}},
    CellDingbat->"\[LongDash]",
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    AutoStyleOptions->{"UnmatchedBracketStyle"->None},
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{80, 18}, {0, 0}},
    CellFrameMargins->12,
    FontSize->15],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{55, 26}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    FormatType->InputForm,
    StyleMenuListing->None,
    Background->GrayLevel[0.700008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{80, 42}, {1, 10}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {2, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, 10}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{80, 18}, {0, 0}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontSlant->"Oblique",
    FontColor->RGBColor[0.6, 0, 0.6]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["CellLabel", "Printout"],
    CellMargins->{{0, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{20, 30}, {45, 5}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CellFrameMargins->{{0, 4}, {8, 4}},
    LineSpacing->{1, 0},
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{28, 40}, {68, 8}},
    FontSize->21],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{18, 30}, {45, 5}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellFrame->False,
    CellMargins->{{18, 140}, {4, 30}},
    LineSpacing->{0.9, 0},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Abstract", "Presentation"],
    CellMargins->{{28, 180}, {6, 42}},
    FontSize->18],
  
  Cell[StyleData["Abstract", "Printout"],
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{55, 10}, {5, 3}},
    PageBreakAbove->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Presentation"],
    CellMargins->{{80, 18}, {6, 6}},
    FontSize->14],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{55, 55}, {5, 4}},
    Hyphenation->True,
    LineSpacing->{1, 2},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{24, 40}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 0},
    FontFamily->"Times"],
  
  Cell[StyleData["Reference", "Presentation"],
    CellMargins->{{38, 40}, {10, 10}},
    FontSize->18],
  
  Cell[StyleData["Reference", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    Hyphenation->True,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 1}, {0, 0}},
    CellMargins->{{55, Inherited}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    Background->GrayLevel[0.850004]],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CellFrame->{{2, 2}, {0, 0}},
    CellMargins->{{80, 6}, {0, 0}},
    CellFrameMargins->12,
    FontSize->18],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{55, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "SlideShow"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "SlideShow"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "SlideShow"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "SlideShow"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLinkText"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLinkText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLinkText", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLinkText", "SlideShow"]],
  
  Cell[StyleData["RefGuideLinkText", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "SlideShow"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DemosLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["DemosLink", "SlideShow"]],
  
  Cell[StyleData["DemosLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TourLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["TourLink", "SlideShow"]],
  
  Cell[StyleData["TourLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "SlideShow"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "SlideShow"]],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{80, 18}, {6, 6}},
    FontSize->18],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    TextJustification->1,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{80, 18}, {6, 0}},
    FontSize->18],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{55, 10}, {Inherited, 0}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{80, 18}, {6, 0}},
    FontSize->18],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, \
etc.  They automatically give the cell a FrameLabel containing a reference to \
a particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 85}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{80, 125}, {6, 6}},
    FontSize->18],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}], FontWeight -> "Bold"], None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    CellMargins->{{80, 145}, {6, 6}},
    FontSize->18],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{55, 95}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}], FontWeight -> "Bold"], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Times"],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{80, 145}, {10, 6}},
    FontSize->18],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, 80}, {4, 4}},
    FontSize->8]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Header", "Presentation"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Presentation"],
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    TextAlignment->Center,
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Footer", "Presentation"],
    FontSize->14]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Slide Show Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowNavigationBar"],
    Editable->False,
    CellFrame->True,
    CellMargins->{{0, 0}, {3, 3}},
    CellElementSpacings->{"CellMinHeight"->0.8125},
    CellGroupingRules->{"SectionGrouping", 30},
    CellFrameMargins->False,
    CellFrameColor->GrayLevel[1],
    CellFrameLabelMargins->False,
    TextAlignment->Center,
    CounterIncrements->"SlideShowNavigationBar",
    StyleMenuListing->None,
    FontSize->10,
    Background->GrayLevel[0.8],
    Magnification->1,
    GridBoxOptions->{GridBaseline->Center,
    RowSpacings->0,
    ColumnSpacings->0,
    ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
    RowAlignments->Baseline,
    ColumnAlignments->{
      Center, Center, Center, Center, Center, Center, Right, Center}}],
  
  Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
    Deletable->False,
    ShowCellBracket->False,
    CellMargins->{{-1, -1}, {-1, -1}},
    PageBreakAbove->True,
    CellFrameMargins->{{1, 1}, {0, 0}}],
  
  Cell[StyleData["SlideShowNavigationBar", "Printout"],
    CellMargins->{{18, 4}, {4, 4}},
    LineSpacing->{1, 3},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideShowSection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{0, 0}, {10, 0}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->{{12, 4}, {6, 12}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica", 
        "gridMathematica"->FormBox[ 
            RowBox[ {"grid", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
            TextForm], Inherited},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Plain",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.408011, 0.440726, 0.8]],
  
  Cell[StyleData["SlideShowSection", "Presentation"],
    CellFrameMargins->{{18, 10}, {10, 18}},
    FontSize->27],
  
  Cell[StyleData["SlideShowSection", "SlideShow"],
    ShowCellBracket->False,
    PageBreakAbove->True],
  
  Cell[StyleData["SlideShowSection", "Printout"],
    CellMargins->{{18, 30}, {0, 30}},
    CellFrameMargins->5,
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideHyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->26,
    FontColor->GrayLevel[0.400015],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMinHeight->0.85,
    ButtonMargins->0.5,
    ButtonNote->None}],
  
  Cell[StyleData["SlideHyperlink", "Presentation"],
    CellMargins->{{10, 10}, {10, 12}},
    FontSize->36],
  
  Cell[StyleData["SlideHyperlink", "SlideShow"]],
  
  Cell[StyleData["SlideHyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOCLink"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Helvetica",
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonMargins->1.5,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["SlideTOCLink", "Presentation"],
    CellMargins->{{35, 10}, {5, 10}},
    FontSize->18],
  
  Cell[StyleData["SlideTOCLink", "SlideShow"]],
  
  Cell[StyleData["SlideTOCLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SlideTOC"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["SlideTOC", "Presentation"],
    CellMargins->{{25, 10}, {10, 5}},
    FontSize->18],
  
  Cell[StyleData["SlideTOC", "SlideShow"],
    FontSize->14],
  
  Cell[StyleData["SlideTOC", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation \
package. These styles serve to make visible otherwise invisible \
tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 56, 0, 51, "Subtitle"],
Cell[1835, 55, 35, 0, 34, "Text"],
Cell[1873, 57, 60, 1, 40, "Input"],
Cell[1936, 60, 330, 9, 40, "Input"],
Cell[2269, 71, 323, 9, 40, "Input"],
Cell[2595, 82, 176, 4, 53, "Text"],

Cell[CellGroupData[{
Cell[2796, 90, 161, 3, 41, "Input"],
Cell[2960, 95, 290, 5, 87, "Output"]
}, Open  ]],
Cell[3265, 103, 47, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[3337, 107, 183, 4, 41, "Input"],
Cell[3523, 113, 682, 11, 152, "Output"]
}, Open  ]],
Cell[4220, 127, 40, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[4285, 131, 139, 3, 66, "Input"],
Cell[4427, 136, 218, 4, 70, "Output"]
}, Open  ]],
Cell[4660, 143, 37, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[4722, 147, 66, 1, 40, "Input"],
Cell[4791, 150, 626, 10, 148, "Output"]
}, Open  ]],
Cell[5432, 163, 36, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[5493, 167, 71, 1, 40, "Input"],
Cell[5567, 170, 768, 12, 218, "Output"]
}, Open  ]],
Cell[6350, 185, 48, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[6423, 189, 52, 1, 40, "Input"],
Cell[6478, 192, 416, 7, 96, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6931, 204, 38, 1, 40, "Input"],
Cell[6972, 207, 527, 9, 139, "Output"]
}, Open  ]],
Cell[7514, 219, 110, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[7649, 226, 133, 3, 40, "Input"],
Cell[7785, 231, 7783, 137, 823, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[15605, 373, 73, 1, 44, "Input"],
Cell[15681, 376, 493, 7, 163, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16211, 388, 75, 1, 40, "Input"],
Cell[16289, 391, 479, 7, 163, "Output"]
}, Open  ]],
Cell[16783, 401, 135, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[16943, 408, 78, 1, 40, "Input"],
Cell[17024, 411, 1325, 19, 475, "Output"]
}, Open  ]],
Cell[18364, 433, 155, 5, 34, "Text"],

Cell[CellGroupData[{
Cell[18544, 442, 758, 12, 147, "Input"],
Cell[19305, 456, 649, 9, 187, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19991, 470, 145, 3, 40, "Input"],
Cell[20139, 475, 1012, 17, 194, "Output"]
}, Open  ]],
Cell[21166, 495, 117, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[21308, 502, 65, 1, 40, "Input"],
Cell[21376, 505, 355, 5, 55, "Message"],
Cell[21734, 512, 1614, 23, 264, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23385, 540, 231, 5, 60, "Input"],
Cell[23619, 547, 128451, 2073, 398, 8550, 588, "GraphicsData", "PostScript", \
"Graphics"],
Cell[152073, 2622, 130, 3, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152240, 2630, 232, 5, 60, "Input"],
Cell[152475, 2637, 81152, 1348, 411, 5988, 416, "GraphicsData", "PostScript", \
"Graphics"],
Cell[233630, 3987, 130, 3, 78, "Output"]
}, Open  ]],
Cell[233775, 3993, 91, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[233891, 4000, 244, 5, 61, "Input"],
Cell[234138, 4007, 275, 4, 99, "Output"]
}, Open  ]],
Cell[234428, 4014, 68, 0, 34, "Text"],

Cell[CellGroupData[{
Cell[234521, 4018, 210, 4, 61, "Input"],
Cell[234734, 4024, 180, 3, 98, "Output"]
}, Open  ]],
Cell[234929, 4030, 96, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[235050, 4037, 258, 4, 60, "Input"],
Cell[235311, 4043, 38, 1, 78, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235386, 4049, 264, 4, 60, "Input"],
Cell[235653, 4055, 38, 1, 78, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

